from .async_client import (
    CustomAudienceServiceAsyncClient as CustomAudienceServiceAsyncClient,
)
from .client import CustomAudienceServiceClient as CustomAudienceServiceClient

__all__ = ["CustomAudienceServiceClient", "CustomAudienceServiceAsyncClient"]



from collections.abc import Callable
from typing import TypeVar

import grpc

import google.ads.googleads.v19.services
import google.ads.googleads.v20.services
import google.ads.googleads.v21.services
import google.ads.googleads.v22.services

from .interceptor import Interceptor

_Request = TypeVar(
    "_Request",
    google.ads.googleads.v19.services.SearchGoogleAdsRequest,
    google.ads.googleads.v19.services.SearchGoogleAdsStreamRequest,
    google.ads.googleads.v20.services.SearchGoogleAdsRequest,
    google.ads.googleads.v20.services.SearchGoogleAdsStreamRequest,
    google.ads.googleads.v21.services.SearchGoogleAdsRequest,
    google.ads.googleads.v21.services.SearchGoogleAdsStreamRequest,
    google.ads.googleads.v22.services.SearchGoogleAdsRequest,
    google.ads.googleads.v22.services.SearchGoogleAdsStreamRequest,
)
_Response = TypeVar("_Response")

class MetadataInterceptor(
    Interceptor, grpc.UnaryUnaryClientInterceptor, grpc.UnaryStreamClientInterceptor
):
    developer_token_meta: tuple[str, str] = ...
    login_customer_id_meta: tuple[str, str] | None = ...
    linked_customer_id_meta: tuple[str, str] | None = ...
    use_cloud_org_for_api_access: bool | None = ...
    def __init__(
        self,
        developer_token: str,
        login_customer_id: str,
        linked_customer_id: str | None = None,
        use_cloud_org_for_api_access: bool | None = None,
    ) -> None: ...
    def intercept_unary_unary(
        self,
        continuation: Callable[[grpc.ClientCallDetails, _Request], _Response],
        client_call_details: grpc.ClientCallDetails,
        request: _Request,
    ) -> _Response: ...
    def intercept_unary_stream(
        self,
        continuation: Callable[[grpc.ClientCallDetails, _Request], _Response],
        client_call_details: grpc.ClientCallDetails,
        request: _Request,
    ) -> _Response: ...



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

_M = TypeVar("_M")

class AdGroupPrimaryStatusReasonEnum(proto.Message):
    class AdGroupPrimaryStatusReason(proto.Enum):
        UNSPECIFIED = 0
        UNKNOWN = 1
        CAMPAIGN_REMOVED = 2
        CAMPAIGN_PAUSED = 3
        CAMPAIGN_PENDING = 4
        CAMPAIGN_ENDED = 5
        AD_GROUP_PAUSED = 6
        AD_GROUP_REMOVED = 7
        AD_GROUP_INCOMPLETE = 8
        KEYWORDS_PAUSED = 9
        NO_KEYWORDS = 10
        AD_GROUP_ADS_PAUSED = 11
        NO_AD_GROUP_ADS = 12
        HAS_ADS_DISAPPROVED = 13
        HAS_ADS_LIMITED_BY_POLICY = 14
        MOST_ADS_UNDER_REVIEW = 15
        CAMPAIGN_DRAFT = 16
        AD_GROUP_PAUSED_DUE_TO_LOW_ACTIVITY = 19

    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: NoReturn
    ) -> bool: ...



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v20.enums.types.brand_state import BrandStateEnum

_M = TypeVar("_M")

class BrandSuggestion(proto.Message):
    id: str
    name: str
    urls: MutableSequence[str]
    state: BrandStateEnum.BrandState
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        id: str = ...,
        name: str = ...,
        urls: MutableSequence[str] = ...,
        state: BrandStateEnum.BrandState = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["id", "name", "urls", "state"]
    ) -> bool: ...

class SuggestBrandsRequest(proto.Message):
    customer_id: str
    brand_prefix: str
    selected_brands: MutableSequence[str]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        brand_prefix: str = ...,
        selected_brands: MutableSequence[str] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["customer_id", "brand_prefix", "selected_brands"]
    ) -> bool: ...

class SuggestBrandsResponse(proto.Message):
    brands: MutableSequence[BrandSuggestion]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        brands: MutableSequence[BrandSuggestion] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["brands"]
    ) -> bool: ...



from .base import AssetSetAssetServiceTransport as AssetSetAssetServiceTransport
from .grpc import AssetSetAssetServiceGrpcTransport as AssetSetAssetServiceGrpcTransport
from .grpc_asyncio import (
    AssetSetAssetServiceGrpcAsyncIOTransport as AssetSetAssetServiceGrpcAsyncIOTransport,
)

__all__ = [
    "AssetSetAssetServiceTransport",
    "AssetSetAssetServiceGrpcTransport",
    "AssetSetAssetServiceGrpcAsyncIOTransport",
]



from .base import (
    CustomerLifecycleGoalServiceTransport as CustomerLifecycleGoalServiceTransport,
)
from .grpc import (
    CustomerLifecycleGoalServiceGrpcTransport as CustomerLifecycleGoalServiceGrpcTransport,
)
from .grpc_asyncio import (
    CustomerLifecycleGoalServiceGrpcAsyncIOTransport as CustomerLifecycleGoalServiceGrpcAsyncIOTransport,
)

__all__ = [
    "CustomerLifecycleGoalServiceTransport",
    "CustomerLifecycleGoalServiceGrpcTransport",
    "CustomerLifecycleGoalServiceGrpcAsyncIOTransport",
]



from .base import (
    CampaignCustomizerServiceTransport as CampaignCustomizerServiceTransport,
)
from .grpc import (
    CampaignCustomizerServiceGrpcTransport as CampaignCustomizerServiceGrpcTransport,
)
from .grpc_asyncio import (
    CampaignCustomizerServiceGrpcAsyncIOTransport as CampaignCustomizerServiceGrpcAsyncIOTransport,
)

__all__ = [
    "CampaignCustomizerServiceTransport",
    "CampaignCustomizerServiceGrpcTransport",
    "CampaignCustomizerServiceGrpcAsyncIOTransport",
]



from .base import (
    CustomerUserAccessInvitationServiceTransport as CustomerUserAccessInvitationServiceTransport,
)
from .grpc import (
    CustomerUserAccessInvitationServiceGrpcTransport as CustomerUserAccessInvitationServiceGrpcTransport,
)
from .grpc_asyncio import (
    CustomerUserAccessInvitationServiceGrpcAsyncIOTransport as CustomerUserAccessInvitationServiceGrpcAsyncIOTransport,
)

__all__ = [
    "CustomerUserAccessInvitationServiceTransport",
    "CustomerUserAccessInvitationServiceGrpcTransport",
    "CustomerUserAccessInvitationServiceGrpcAsyncIOTransport",
]



from .base import AdGroupAdLabelServiceTransport as AdGroupAdLabelServiceTransport
from .grpc import (
    AdGroupAdLabelServiceGrpcTransport as AdGroupAdLabelServiceGrpcTransport,
)
from .grpc_asyncio import (
    AdGroupAdLabelServiceGrpcAsyncIOTransport as AdGroupAdLabelServiceGrpcAsyncIOTransport,
)

__all__ = [
    "AdGroupAdLabelServiceTransport",
    "AdGroupAdLabelServiceGrpcTransport",
    "AdGroupAdLabelServiceGrpcAsyncIOTransport",
]



from . import (
    common as common,
    enums as enums,
    errors as errors,
    resources as resources,
    services as services,
)

__all__ = ["common", "enums", "errors", "resources", "services"]



from .async_client import AdParameterServiceAsyncClient as AdParameterServiceAsyncClient
from .client import AdParameterServiceClient as AdParameterServiceClient

__all__ = ["AdParameterServiceClient", "AdParameterServiceAsyncClient"]



from .base import KeywordPlanServiceTransport as KeywordPlanServiceTransport
from .grpc import KeywordPlanServiceGrpcTransport as KeywordPlanServiceGrpcTransport
from .grpc_asyncio import (
    KeywordPlanServiceGrpcAsyncIOTransport as KeywordPlanServiceGrpcAsyncIOTransport,
)

__all__ = [
    "KeywordPlanServiceTransport",
    "KeywordPlanServiceGrpcTransport",
    "KeywordPlanServiceGrpcAsyncIOTransport",
]



from typing import Any, AsyncIterator, Awaitable, Callable, Iterator, Sequence

from _typeshed import Incomplete
from google.rpc import status_pb2 as status_pb2

from google.ads.googleads.v19.services.types import experiment_service

OptionalRetry: Incomplete
OptionalAsyncRetry: Incomplete

class ListExperimentAsyncErrorsPager:
    def __init__(
        self,
        method: Callable[..., experiment_service.ListExperimentAsyncErrorsResponse],
        request: experiment_service.ListExperimentAsyncErrorsRequest,
        response: experiment_service.ListExperimentAsyncErrorsResponse,
        *,
        retry: OptionalRetry = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str | bytes]] = (),
    ) -> None: ...
    def __getattr__(self, name: str) -> Any: ...
    @property
    def pages(
        self,
    ) -> Iterator[experiment_service.ListExperimentAsyncErrorsResponse]: ...
    def __iter__(self) -> Iterator[status_pb2.Status]: ...

class ListExperimentAsyncErrorsAsyncPager:
    def __init__(
        self,
        method: Callable[
            ..., Awaitable[experiment_service.ListExperimentAsyncErrorsResponse]
        ],
        request: experiment_service.ListExperimentAsyncErrorsRequest,
        response: experiment_service.ListExperimentAsyncErrorsResponse,
        *,
        retry: OptionalAsyncRetry = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str | bytes]] = (),
    ) -> None: ...
    def __getattr__(self, name: str) -> Any: ...
    @property
    async def pages(
        self,
    ) -> AsyncIterator[experiment_service.ListExperimentAsyncErrorsResponse]: ...
    def __aiter__(self) -> AsyncIterator[status_pb2.Status]: ...



from .base import ProductLinkServiceTransport as ProductLinkServiceTransport
from .grpc import ProductLinkServiceGrpcTransport as ProductLinkServiceGrpcTransport
from .grpc_asyncio import (
    ProductLinkServiceGrpcAsyncIOTransport as ProductLinkServiceGrpcAsyncIOTransport,
)

__all__ = [
    "ProductLinkServiceTransport",
    "ProductLinkServiceGrpcTransport",
    "ProductLinkServiceGrpcAsyncIOTransport",
]



from .base import (
    AccountBudgetProposalServiceTransport as AccountBudgetProposalServiceTransport,
)
from .grpc import (
    AccountBudgetProposalServiceGrpcTransport as AccountBudgetProposalServiceGrpcTransport,
)
from .grpc_asyncio import (
    AccountBudgetProposalServiceGrpcAsyncIOTransport as AccountBudgetProposalServiceGrpcAsyncIOTransport,
)

__all__ = [
    "AccountBudgetProposalServiceTransport",
    "AccountBudgetProposalServiceGrpcTransport",
    "AccountBudgetProposalServiceGrpcAsyncIOTransport",
]



from .base import (
    BiddingDataExclusionServiceTransport as BiddingDataExclusionServiceTransport,
)
from .grpc import (
    BiddingDataExclusionServiceGrpcTransport as BiddingDataExclusionServiceGrpcTransport,
)
from .grpc_asyncio import (
    BiddingDataExclusionServiceGrpcAsyncIOTransport as BiddingDataExclusionServiceGrpcAsyncIOTransport,
)

__all__ = [
    "BiddingDataExclusionServiceTransport",
    "BiddingDataExclusionServiceGrpcTransport",
    "BiddingDataExclusionServiceGrpcAsyncIOTransport",
]



from .base import ExperimentServiceTransport as ExperimentServiceTransport
from .grpc import ExperimentServiceGrpcTransport as ExperimentServiceGrpcTransport
from .grpc_asyncio import (
    ExperimentServiceGrpcAsyncIOTransport as ExperimentServiceGrpcAsyncIOTransport,
)

__all__ = [
    "ExperimentServiceTransport",
    "ExperimentServiceGrpcTransport",
    "ExperimentServiceGrpcAsyncIOTransport",
]



from .base import AssetGroupServiceTransport as AssetGroupServiceTransport
from .grpc import AssetGroupServiceGrpcTransport as AssetGroupServiceGrpcTransport
from .grpc_asyncio import (
    AssetGroupServiceGrpcAsyncIOTransport as AssetGroupServiceGrpcAsyncIOTransport,
)

__all__ = [
    "AssetGroupServiceTransport",
    "AssetGroupServiceGrpcTransport",
    "AssetGroupServiceGrpcAsyncIOTransport",
]



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v20.enums.types.sk_ad_network_coarse_conversion_value import (
    SkAdNetworkCoarseConversionValueEnum,
)

_M = TypeVar("_M")

class CustomerSkAdNetworkConversionValueSchema(proto.Message):
    class SkAdNetworkConversionValueSchema(proto.Message):
        class CoarseGrainedConversionValueMappings(proto.Message):
            low_conversion_value_mapping: CustomerSkAdNetworkConversionValueSchema.SkAdNetworkConversionValueSchema.ConversionValueMapping
            medium_conversion_value_mapping: CustomerSkAdNetworkConversionValueSchema.SkAdNetworkConversionValueSchema.ConversionValueMapping
            high_conversion_value_mapping: CustomerSkAdNetworkConversionValueSchema.SkAdNetworkConversionValueSchema.ConversionValueMapping
            def __init__(
                self: _M,
                mapping: _M | Mapping | google.protobuf.message.Message | None = None,
                *,
                ignore_unknown_fields: bool = False,
                low_conversion_value_mapping: CustomerSkAdNetworkConversionValueSchema.SkAdNetworkConversionValueSchema.ConversionValueMapping = ...,
                medium_conversion_value_mapping: CustomerSkAdNetworkConversionValueSchema.SkAdNetworkConversionValueSchema.ConversionValueMapping = ...,
                high_conversion_value_mapping: CustomerSkAdNetworkConversionValueSchema.SkAdNetworkConversionValueSchema.ConversionValueMapping = ...,
            ) -> None: ...
            def __contains__(  # type: ignore[override]
                self,
                key: Literal[
                    "low_conversion_value_mapping",
                    "medium_conversion_value_mapping",
                    "high_conversion_value_mapping",
                ],
            ) -> bool: ...

        class ConversionValueMapping(proto.Message):
            min_time_post_install_hours: int
            max_time_post_install_hours: int
            mapped_events: MutableSequence[
                CustomerSkAdNetworkConversionValueSchema.SkAdNetworkConversionValueSchema.Event
            ]
            def __init__(
                self: _M,
                mapping: _M | Mapping | google.protobuf.message.Message | None = None,
                *,
                ignore_unknown_fields: bool = False,
                min_time_post_install_hours: int = ...,
                max_time_post_install_hours: int = ...,
                mapped_events: MutableSequence[
                    CustomerSkAdNetworkConversionValueSchema.SkAdNetworkConversionValueSchema.Event
                ] = ...,
            ) -> None: ...
            def __contains__(  # type: ignore[override]
                self,
                key: Literal[
                    "min_time_post_install_hours",
                    "max_time_post_install_hours",
                    "mapped_events",
                ],
            ) -> bool: ...

        class Event(proto.Message):
            class EventOccurrenceRange(proto.Message):
                min_event_count: int
                max_event_count: int
                def __init__(
                    self: _M,
                    mapping: _M
                    | Mapping
                    | google.protobuf.message.Message
                    | None = None,
                    *,
                    ignore_unknown_fields: bool = False,
                    min_event_count: int = ...,
                    max_event_count: int = ...,
                ) -> None: ...
                def __contains__(  # type: ignore[override]
                    self, key: Literal["min_event_count", "max_event_count"]
                ) -> bool: ...

            class RevenueRange(proto.Message):
                min_event_revenue: float
                max_event_revenue: float
                def __init__(
                    self: _M,
                    mapping: _M
                    | Mapping
                    | google.protobuf.message.Message
                    | None = None,
                    *,
                    ignore_unknown_fields: bool = False,
                    min_event_revenue: float = ...,
                    max_event_revenue: float = ...,
                ) -> None: ...
                def __contains__(  # type: ignore[override]
                    self, key: Literal["min_event_revenue", "max_event_revenue"]
                ) -> bool: ...

            mapped_event_name: str
            currency_code: str
            event_revenue_range: CustomerSkAdNetworkConversionValueSchema.SkAdNetworkConversionValueSchema.Event.RevenueRange
            event_revenue_value: float
            event_occurrence_range: CustomerSkAdNetworkConversionValueSchema.SkAdNetworkConversionValueSchema.Event.EventOccurrenceRange
            event_counter: int
            def __init__(
                self: _M,
                mapping: _M | Mapping | google.protobuf.message.Message | None = None,
                *,
                ignore_unknown_fields: bool = False,
                mapped_event_name: str = ...,
                currency_code: str = ...,
                event_revenue_range: CustomerSkAdNetworkConversionValueSchema.SkAdNetworkConversionValueSchema.Event.RevenueRange = ...,
                event_revenue_value: float = ...,
                event_occurrence_range: CustomerSkAdNetworkConversionValueSchema.SkAdNetworkConversionValueSchema.Event.EventOccurrenceRange = ...,
                event_counter: int = ...,
            ) -> None: ...
            def __contains__(  # type: ignore[override]
                self,
                key: Literal[
                    "mapped_event_name",
                    "currency_code",
                    "event_revenue_range",
                    "event_revenue_value",
                    "event_occurrence_range",
                    "event_counter",
                ],
            ) -> bool: ...

        class FineGrainedConversionValueMappings(proto.Message):
            fine_grained_conversion_value: int
            conversion_value_mapping: CustomerSkAdNetworkConversionValueSchema.SkAdNetworkConversionValueSchema.ConversionValueMapping
            def __init__(
                self: _M,
                mapping: _M | Mapping | google.protobuf.message.Message | None = None,
                *,
                ignore_unknown_fields: bool = False,
                fine_grained_conversion_value: int = ...,
                conversion_value_mapping: CustomerSkAdNetworkConversionValueSchema.SkAdNetworkConversionValueSchema.ConversionValueMapping = ...,
            ) -> None: ...
            def __contains__(  # type: ignore[override]
                self,
                key: Literal[
                    "fine_grained_conversion_value", "conversion_value_mapping"
                ],
            ) -> bool: ...

        class PostbackMapping(proto.Message):
            postback_sequence_index: int
            coarse_grained_conversion_value_mappings: CustomerSkAdNetworkConversionValueSchema.SkAdNetworkConversionValueSchema.CoarseGrainedConversionValueMappings
            lock_window_coarse_conversion_value: (
                SkAdNetworkCoarseConversionValueEnum.SkAdNetworkCoarseConversionValue
            )
            lock_window_fine_conversion_value: int
            lock_window_event: str
            def __init__(
                self: _M,
                mapping: _M | Mapping | google.protobuf.message.Message | None = None,
                *,
                ignore_unknown_fields: bool = False,
                postback_sequence_index: int = ...,
                coarse_grained_conversion_value_mappings: CustomerSkAdNetworkConversionValueSchema.SkAdNetworkConversionValueSchema.CoarseGrainedConversionValueMappings = ...,
                lock_window_coarse_conversion_value: SkAdNetworkCoarseConversionValueEnum.SkAdNetworkCoarseConversionValue = ...,
                lock_window_fine_conversion_value: int = ...,
                lock_window_event: str = ...,
            ) -> None: ...
            def __contains__(  # type: ignore[override]
                self,
                key: Literal[
                    "postback_sequence_index",
                    "coarse_grained_conversion_value_mappings",
                    "lock_window_coarse_conversion_value",
                    "lock_window_fine_conversion_value",
                    "lock_window_event",
                ],
            ) -> bool: ...

        app_id: str
        measurement_window_hours: int
        fine_grained_conversion_value_mappings: MutableSequence[
            CustomerSkAdNetworkConversionValueSchema.SkAdNetworkConversionValueSchema.FineGrainedConversionValueMappings
        ]
        postback_mappings: MutableSequence[
            CustomerSkAdNetworkConversionValueSchema.SkAdNetworkConversionValueSchema.PostbackMapping
        ]
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            app_id: str = ...,
            measurement_window_hours: int = ...,
            fine_grained_conversion_value_mappings: MutableSequence[
                CustomerSkAdNetworkConversionValueSchema.SkAdNetworkConversionValueSchema.FineGrainedConversionValueMappings
            ] = ...,
            postback_mappings: MutableSequence[
                CustomerSkAdNetworkConversionValueSchema.SkAdNetworkConversionValueSchema.PostbackMapping
            ] = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self,
            key: Literal[
                "app_id",
                "measurement_window_hours",
                "fine_grained_conversion_value_mappings",
                "postback_mappings",
            ],
        ) -> bool: ...

    resource_name: str
    schema: CustomerSkAdNetworkConversionValueSchema.SkAdNetworkConversionValueSchema
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        schema: CustomerSkAdNetworkConversionValueSchema.SkAdNetworkConversionValueSchema = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["resource_name", "schema"]
    ) -> bool: ...



from .async_client import (
    IdentityVerificationServiceAsyncClient as IdentityVerificationServiceAsyncClient,
)
from .client import (
    IdentityVerificationServiceClient as IdentityVerificationServiceClient,
)

__all__ = [
    "IdentityVerificationServiceClient",
    "IdentityVerificationServiceAsyncClient",
]



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v22.common.types.offline_user_data import (
    CustomerMatchUserListMetadata,
    UserData,
)

_M = TypeVar("_M")

class UploadUserDataRequest(proto.Message):
    customer_id: str
    operations: MutableSequence[UserDataOperation]
    customer_match_user_list_metadata: CustomerMatchUserListMetadata
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        operations: MutableSequence[UserDataOperation] = ...,
        customer_match_user_list_metadata: CustomerMatchUserListMetadata = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal["customer_id", "operations", "customer_match_user_list_metadata"],
    ) -> bool: ...

class UploadUserDataResponse(proto.Message):
    upload_date_time: str
    received_operations_count: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        upload_date_time: str = ...,
        received_operations_count: int = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["upload_date_time", "received_operations_count"]
    ) -> bool: ...

class UserDataOperation(proto.Message):
    create: UserData
    remove: UserData
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        create: UserData = ...,
        remove: UserData = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["create", "remove"]
    ) -> bool: ...



from .base import (
    CustomerManagerLinkServiceTransport as CustomerManagerLinkServiceTransport,
)
from .grpc import (
    CustomerManagerLinkServiceGrpcTransport as CustomerManagerLinkServiceGrpcTransport,
)
from .grpc_asyncio import (
    CustomerManagerLinkServiceGrpcAsyncIOTransport as CustomerManagerLinkServiceGrpcAsyncIOTransport,
)

__all__ = [
    "CustomerManagerLinkServiceTransport",
    "CustomerManagerLinkServiceGrpcTransport",
    "CustomerManagerLinkServiceGrpcAsyncIOTransport",
]



from .async_client import (
    CustomerAssetSetServiceAsyncClient as CustomerAssetSetServiceAsyncClient,
)
from .client import CustomerAssetSetServiceClient as CustomerAssetSetServiceClient

__all__ = ["CustomerAssetSetServiceClient", "CustomerAssetSetServiceAsyncClient"]



from .async_client import (
    CampaignBidModifierServiceAsyncClient as CampaignBidModifierServiceAsyncClient,
)
from .client import CampaignBidModifierServiceClient as CampaignBidModifierServiceClient

__all__ = ["CampaignBidModifierServiceClient", "CampaignBidModifierServiceAsyncClient"]



from .base import (
    IdentityVerificationServiceTransport as IdentityVerificationServiceTransport,
)
from .grpc import (
    IdentityVerificationServiceGrpcTransport as IdentityVerificationServiceGrpcTransport,
)
from .grpc_asyncio import (
    IdentityVerificationServiceGrpcAsyncIOTransport as IdentityVerificationServiceGrpcAsyncIOTransport,
)

__all__ = [
    "IdentityVerificationServiceTransport",
    "IdentityVerificationServiceGrpcTransport",
    "IdentityVerificationServiceGrpcAsyncIOTransport",
]



from .base import (
    CustomerUserAccessServiceTransport as CustomerUserAccessServiceTransport,
)
from .grpc import (
    CustomerUserAccessServiceGrpcTransport as CustomerUserAccessServiceGrpcTransport,
)
from .grpc_asyncio import (
    CustomerUserAccessServiceGrpcAsyncIOTransport as CustomerUserAccessServiceGrpcAsyncIOTransport,
)

__all__ = [
    "CustomerUserAccessServiceTransport",
    "CustomerUserAccessServiceGrpcTransport",
    "CustomerUserAccessServiceGrpcAsyncIOTransport",
]



from .async_client import (
    CustomerCustomizerServiceAsyncClient as CustomerCustomizerServiceAsyncClient,
)
from .client import CustomerCustomizerServiceClient as CustomerCustomizerServiceClient

__all__ = ["CustomerCustomizerServiceClient", "CustomerCustomizerServiceAsyncClient"]



from typing import Any, AsyncIterator, Awaitable, Callable, Iterator, Sequence

from _typeshed import Incomplete

from google.ads.googleads.v19.services.types import keyword_plan_idea_service

OptionalRetry: Incomplete
OptionalAsyncRetry: Incomplete

class GenerateKeywordIdeasPager:
    def __init__(
        self,
        method: Callable[..., keyword_plan_idea_service.GenerateKeywordIdeaResponse],
        request: keyword_plan_idea_service.GenerateKeywordIdeasRequest,
        response: keyword_plan_idea_service.GenerateKeywordIdeaResponse,
        *,
        retry: OptionalRetry = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str | bytes]] = (),
    ) -> None: ...
    def __getattr__(self, name: str) -> Any: ...
    @property
    def pages(
        self,
    ) -> Iterator[keyword_plan_idea_service.GenerateKeywordIdeaResponse]: ...
    def __iter__(
        self,
    ) -> Iterator[keyword_plan_idea_service.GenerateKeywordIdeaResult]: ...

class GenerateKeywordIdeasAsyncPager:
    def __init__(
        self,
        method: Callable[
            ..., Awaitable[keyword_plan_idea_service.GenerateKeywordIdeaResponse]
        ],
        request: keyword_plan_idea_service.GenerateKeywordIdeasRequest,
        response: keyword_plan_idea_service.GenerateKeywordIdeaResponse,
        *,
        retry: OptionalAsyncRetry = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str | bytes]] = (),
    ) -> None: ...
    def __getattr__(self, name: str) -> Any: ...
    @property
    async def pages(
        self,
    ) -> AsyncIterator[keyword_plan_idea_service.GenerateKeywordIdeaResponse]: ...
    def __aiter__(
        self,
    ) -> AsyncIterator[keyword_plan_idea_service.GenerateKeywordIdeaResult]: ...



from .async_client import (
    KeywordPlanCampaignServiceAsyncClient as KeywordPlanCampaignServiceAsyncClient,
)
from .client import KeywordPlanCampaignServiceClient as KeywordPlanCampaignServiceClient

__all__ = ["KeywordPlanCampaignServiceClient", "KeywordPlanCampaignServiceAsyncClient"]



from .async_client import (
    RecommendationSubscriptionServiceAsyncClient as RecommendationSubscriptionServiceAsyncClient,
)
from .client import (
    RecommendationSubscriptionServiceClient as RecommendationSubscriptionServiceClient,
)

__all__ = [
    "RecommendationSubscriptionServiceClient",
    "RecommendationSubscriptionServiceAsyncClient",
]



from .base import AssetGroupAssetServiceTransport as AssetGroupAssetServiceTransport
from .grpc import (
    AssetGroupAssetServiceGrpcTransport as AssetGroupAssetServiceGrpcTransport,
)
from .grpc_asyncio import (
    AssetGroupAssetServiceGrpcAsyncIOTransport as AssetGroupAssetServiceGrpcAsyncIOTransport,
)

__all__ = [
    "AssetGroupAssetServiceTransport",
    "AssetGroupAssetServiceGrpcTransport",
    "AssetGroupAssetServiceGrpcAsyncIOTransport",
]



import types
from typing import Callable, MutableSequence, Sequence

from _typeshed import Incomplete
from google.api_core import (
    client_options as client_options_lib,
    gapic_v1,
    retry as retries,
)
from google.auth import credentials as ga_credentials

from google.ads.googleads.v19.common.types import audience_insights_attribute, criteria
from google.ads.googleads.v19.enums.types import audience_insights_dimension
from google.ads.googleads.v19.services.types import audience_insights_service

from .transports.base import AudienceInsightsServiceTransport

__all__ = ["AudienceInsightsServiceClient"]

class AudienceInsightsServiceClientMeta(type):
    def get_transport_class(
        cls, label: str | None = None
    ) -> type[AudienceInsightsServiceTransport]: ...

class AudienceInsightsServiceClient(metaclass=AudienceInsightsServiceClientMeta):
    DEFAULT_ENDPOINT: str
    DEFAULT_MTLS_ENDPOINT: Incomplete
    @classmethod
    def from_service_account_info(cls, info: dict, *args, **kwargs): ...
    @classmethod
    def from_service_account_file(cls, filename: str, *args, **kwargs): ...
    from_service_account_json = from_service_account_file
    @property
    def transport(self) -> AudienceInsightsServiceTransport: ...
    @staticmethod
    def common_billing_account_path(billing_account: str) -> str: ...
    @staticmethod
    def parse_common_billing_account_path(path: str) -> dict[str, str]: ...
    @staticmethod
    def common_folder_path(folder: str) -> str: ...
    @staticmethod
    def parse_common_folder_path(path: str) -> dict[str, str]: ...
    @staticmethod
    def common_organization_path(organization: str) -> str: ...
    @staticmethod
    def parse_common_organization_path(path: str) -> dict[str, str]: ...
    @staticmethod
    def common_project_path(project: str) -> str: ...
    @staticmethod
    def parse_common_project_path(path: str) -> dict[str, str]: ...
    @staticmethod
    def common_location_path(project: str, location: str) -> str: ...
    @staticmethod
    def parse_common_location_path(path: str) -> dict[str, str]: ...
    @classmethod
    def get_mtls_endpoint_and_cert_source(
        cls, client_options: client_options_lib.ClientOptions | None = None
    ): ...
    @property
    def api_endpoint(self): ...
    @property
    def universe_domain(self) -> str: ...
    def __init__(
        self,
        *,
        credentials: ga_credentials.Credentials | None = None,
        transport: str
        | AudienceInsightsServiceTransport
        | Callable[..., AudienceInsightsServiceTransport]
        | None = None,
        client_options: client_options_lib.ClientOptions | dict | None = None,
        client_info: gapic_v1.client_info.ClientInfo = ...,
    ) -> None: ...
    def generate_insights_finder_report(
        self,
        request: audience_insights_service.GenerateInsightsFinderReportRequest
        | dict
        | None = None,
        *,
        customer_id: str | None = None,
        baseline_audience: audience_insights_service.BasicInsightsAudience
        | None = None,
        specific_audience: audience_insights_service.BasicInsightsAudience
        | None = None,
        retry: retries.Retry | gapic_v1.method._MethodDefault = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str | bytes]] = (),
    ) -> audience_insights_service.GenerateInsightsFinderReportResponse: ...
    def list_audience_insights_attributes(
        self,
        request: audience_insights_service.ListAudienceInsightsAttributesRequest
        | dict
        | None = None,
        *,
        customer_id: str | None = None,
        dimensions: MutableSequence[
            audience_insights_dimension.AudienceInsightsDimensionEnum.AudienceInsightsDimension
        ]
        | None = None,
        query_text: str | None = None,
        retry: retries.Retry | gapic_v1.method._MethodDefault = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str | bytes]] = (),
    ) -> audience_insights_service.ListAudienceInsightsAttributesResponse: ...
    def list_insights_eligible_dates(
        self,
        request: audience_insights_service.ListInsightsEligibleDatesRequest
        | dict
        | None = None,
        *,
        retry: retries.Retry | gapic_v1.method._MethodDefault = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str | bytes]] = (),
    ) -> audience_insights_service.ListInsightsEligibleDatesResponse: ...
    def generate_audience_composition_insights(
        self,
        request: audience_insights_service.GenerateAudienceCompositionInsightsRequest
        | dict
        | None = None,
        *,
        customer_id: str | None = None,
        audience: audience_insights_service.InsightsAudience | None = None,
        dimensions: MutableSequence[
            audience_insights_dimension.AudienceInsightsDimensionEnum.AudienceInsightsDimension
        ]
        | None = None,
        retry: retries.Retry | gapic_v1.method._MethodDefault = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str | bytes]] = (),
    ) -> audience_insights_service.GenerateAudienceCompositionInsightsResponse: ...
    def generate_suggested_targeting_insights(
        self,
        request: audience_insights_service.GenerateSuggestedTargetingInsightsRequest
        | dict
        | None = None,
        *,
        retry: retries.Retry | gapic_v1.method._MethodDefault = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str | bytes]] = (),
    ) -> audience_insights_service.GenerateSuggestedTargetingInsightsResponse: ...
    def generate_audience_overlap_insights(
        self,
        request: audience_insights_service.GenerateAudienceOverlapInsightsRequest
        | dict
        | None = None,
        *,
        customer_id: str | None = None,
        country_location: criteria.LocationInfo | None = None,
        primary_attribute: audience_insights_attribute.AudienceInsightsAttribute
        | None = None,
        dimensions: MutableSequence[
            audience_insights_dimension.AudienceInsightsDimensionEnum.AudienceInsightsDimension
        ]
        | None = None,
        retry: retries.Retry | gapic_v1.method._MethodDefault = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str | bytes]] = (),
    ) -> audience_insights_service.GenerateAudienceOverlapInsightsResponse: ...
    def generate_targeting_suggestion_metrics(
        self,
        request: audience_insights_service.GenerateTargetingSuggestionMetricsRequest
        | dict
        | None = None,
        *,
        customer_id: str | None = None,
        audiences: MutableSequence[audience_insights_service.BasicInsightsAudience]
        | None = None,
        retry: retries.Retry | gapic_v1.method._MethodDefault = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str | bytes]] = (),
    ) -> audience_insights_service.GenerateTargetingSuggestionMetricsResponse: ...
    def __enter__(self) -> AudienceInsightsServiceClient: ...
    def __exit__(
        self,
        type: type[BaseException] | None,
        value: BaseException | None,
        traceback: types.TracebackType | None,
    ) -> None: ...



from .base import AudienceInsightsServiceTransport as AudienceInsightsServiceTransport
from .grpc import (
    AudienceInsightsServiceGrpcTransport as AudienceInsightsServiceGrpcTransport,
)
from .grpc_asyncio import (
    AudienceInsightsServiceGrpcAsyncIOTransport as AudienceInsightsServiceGrpcAsyncIOTransport,
)

__all__ = [
    "AudienceInsightsServiceTransport",
    "AudienceInsightsServiceGrpcTransport",
    "AudienceInsightsServiceGrpcAsyncIOTransport",
]



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from google.rpc.status_pb2 import Status
from typing_extensions import Literal

from google.ads.googleads.v21.common.types.offline_user_data import UserIdentifier
from google.ads.googleads.v21.enums.types.conversion_adjustment_type import (
    ConversionAdjustmentTypeEnum,
)

_M = TypeVar("_M")

class ConversionAdjustment(proto.Message):
    gclid_date_time_pair: GclidDateTimePair
    order_id: str
    conversion_action: str
    adjustment_date_time: str
    adjustment_type: ConversionAdjustmentTypeEnum.ConversionAdjustmentType
    restatement_value: RestatementValue
    user_identifiers: MutableSequence[UserIdentifier]
    user_agent: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        gclid_date_time_pair: GclidDateTimePair = ...,
        order_id: str = ...,
        conversion_action: str = ...,
        adjustment_date_time: str = ...,
        adjustment_type: ConversionAdjustmentTypeEnum.ConversionAdjustmentType = ...,
        restatement_value: RestatementValue = ...,
        user_identifiers: MutableSequence[UserIdentifier] = ...,
        user_agent: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "gclid_date_time_pair",
            "order_id",
            "conversion_action",
            "adjustment_date_time",
            "adjustment_type",
            "restatement_value",
            "user_identifiers",
            "user_agent",
        ],
    ) -> bool: ...

class ConversionAdjustmentResult(proto.Message):
    gclid_date_time_pair: GclidDateTimePair
    order_id: str
    conversion_action: str
    adjustment_date_time: str
    adjustment_type: ConversionAdjustmentTypeEnum.ConversionAdjustmentType
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        gclid_date_time_pair: GclidDateTimePair = ...,
        order_id: str = ...,
        conversion_action: str = ...,
        adjustment_date_time: str = ...,
        adjustment_type: ConversionAdjustmentTypeEnum.ConversionAdjustmentType = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "gclid_date_time_pair",
            "order_id",
            "conversion_action",
            "adjustment_date_time",
            "adjustment_type",
        ],
    ) -> bool: ...

class GclidDateTimePair(proto.Message):
    gclid: str
    conversion_date_time: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        gclid: str = ...,
        conversion_date_time: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["gclid", "conversion_date_time"]
    ) -> bool: ...

class RestatementValue(proto.Message):
    adjusted_value: float
    currency_code: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        adjusted_value: float = ...,
        currency_code: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["adjusted_value", "currency_code"]
    ) -> bool: ...

class UploadConversionAdjustmentsRequest(proto.Message):
    customer_id: str
    conversion_adjustments: MutableSequence[ConversionAdjustment]
    partial_failure: bool
    validate_only: bool
    job_id: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        conversion_adjustments: MutableSequence[ConversionAdjustment] = ...,
        partial_failure: bool = ...,
        validate_only: bool = ...,
        job_id: int = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "customer_id",
            "conversion_adjustments",
            "partial_failure",
            "validate_only",
            "job_id",
        ],
    ) -> bool: ...

class UploadConversionAdjustmentsResponse(proto.Message):
    partial_failure_error: Status
    results: MutableSequence[ConversionAdjustmentResult]
    job_id: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        partial_failure_error: Status = ...,
        results: MutableSequence[ConversionAdjustmentResult] = ...,
        job_id: int = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["partial_failure_error", "results", "job_id"]
    ) -> bool: ...



from .async_client import (
    CampaignAssetSetServiceAsyncClient as CampaignAssetSetServiceAsyncClient,
)
from .client import CampaignAssetSetServiceClient as CampaignAssetSetServiceClient

__all__ = ["CampaignAssetSetServiceClient", "CampaignAssetSetServiceAsyncClient"]



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

_M = TypeVar("_M")

class AssetGenerationErrorEnum(proto.Message):
    class AssetGenerationError(proto.Enum):
        UNSPECIFIED = 0
        UNKNOWN = 1
        NO_ASSETS_GENERATED = 2
        FINAL_URL_REQUIRED = 3
        GENERATION_CONTEXT_MISSING_FINAL_URL = 4
        FINAL_URL_SENSITIVE = 5
        FINAL_URL_UNSUPPORTED_LANGUAGE = 6
        FINAL_URL_UNAVAILABLE = 7
        CAMPAIGN_TYPE_REQUIRED = 8
        UNSUPPORTED_CAMPAIGN_TYPE = 9
        UNSUPPORTED_FIELD_TYPE = 10
        UNSUPPORTED_FIELD_TYPE_FOR_CAMPAIGN_TYPE = 11
        FREEFORM_PROMPT_UNSUPPORTED_LANGUAGE = 12
        FREEFORM_PROMPT_SENSITIVE = 13
        INPUT_IMAGE_FILE_SIZE_TOO_LARGE = 14
        INPUT_IMAGE_EMPTY = 15
        GENERATION_TYPE_REQUIRED = 16
        TOO_MANY_KEYWORDS = 17
        KEYWORD_INVALID_LENGTH = 18
        NO_VALID_KEYWORDS = 19
        FREEFORM_PROMPT_INVALID_LENGTH = 20
        FREEFORM_PROMPT_REFERENCES_CHILDREN = 21
        FREEFORM_PROMPT_REFERENCES_SPECIFIC_PEOPLE = 22
        FREEFORM_PROMPT_VIOLATES_ADS_POLICY = 23
        FREEFORM_PROMPT_BRAND_CONTENT = 24
        INPUT_IMAGE_DEPICTS_CHILDREN = 25
        INPUT_IMAGE_CONTAINS_BRAND_CONTENT = 26
        INPUT_IMAGE_SENSITIVE = 27
        INPUT_IMAGE_VIOLATES_POLICY = 28
        ALL_OUTPUT_IMAGES_FILTERED_OUT_CHILDREN_DEPICTION = 29
        ALL_OUTPUT_IMAGES_FILTERED_OUT_SPECIFIC_PEOPLE = 30
        ALL_OUTPUT_IMAGES_FILTERED_OUT = 31
        INPUT_IMAGE_REQUIRED = 32
        INPUT_IMAGE_UNSUPPORTED_IMAGE_TYPE = 33
        CONTEXT_ASSET_GROUP_NOT_FOUND = 34
        CONTEXT_AD_GROUP_AD_NOT_FOUND = 35
        CONTEXT_CAMPAIGN_NOT_FOUND = 36

    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: NoReturn
    ) -> bool: ...



from typing import Any, AsyncIterator, Awaitable, Callable, Iterator, Sequence

from _typeshed import Incomplete

from google.ads.googleads.v19.resources.types import (
    google_ads_field as google_ads_field,
)
from google.ads.googleads.v19.services.types import google_ads_field_service

OptionalRetry: Incomplete
OptionalAsyncRetry: Incomplete

class SearchGoogleAdsFieldsPager:
    def __init__(
        self,
        method: Callable[..., google_ads_field_service.SearchGoogleAdsFieldsResponse],
        request: google_ads_field_service.SearchGoogleAdsFieldsRequest,
        response: google_ads_field_service.SearchGoogleAdsFieldsResponse,
        *,
        retry: OptionalRetry = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str | bytes]] = (),
    ) -> None: ...
    def __getattr__(self, name: str) -> Any: ...
    @property
    def pages(
        self,
    ) -> Iterator[google_ads_field_service.SearchGoogleAdsFieldsResponse]: ...
    def __iter__(self) -> Iterator[google_ads_field.GoogleAdsField]: ...

class SearchGoogleAdsFieldsAsyncPager:
    def __init__(
        self,
        method: Callable[
            ..., Awaitable[google_ads_field_service.SearchGoogleAdsFieldsResponse]
        ],
        request: google_ads_field_service.SearchGoogleAdsFieldsRequest,
        response: google_ads_field_service.SearchGoogleAdsFieldsResponse,
        *,
        retry: OptionalAsyncRetry = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str | bytes]] = (),
    ) -> None: ...
    def __getattr__(self, name: str) -> Any: ...
    @property
    async def pages(
        self,
    ) -> AsyncIterator[google_ads_field_service.SearchGoogleAdsFieldsResponse]: ...
    def __aiter__(self) -> AsyncIterator[google_ads_field.GoogleAdsField]: ...



from .base import AdGroupAssetSetServiceTransport as AdGroupAssetSetServiceTransport
from .grpc import (
    AdGroupAssetSetServiceGrpcTransport as AdGroupAssetSetServiceGrpcTransport,
)
from .grpc_asyncio import (
    AdGroupAssetSetServiceGrpcAsyncIOTransport as AdGroupAssetSetServiceGrpcAsyncIOTransport,
)

__all__ = [
    "AdGroupAssetSetServiceTransport",
    "AdGroupAssetSetServiceGrpcTransport",
    "AdGroupAssetSetServiceGrpcAsyncIOTransport",
]



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v21.enums.types.data_link_status import DataLinkStatusEnum
from google.ads.googleads.v21.enums.types.data_link_type import DataLinkTypeEnum

_M = TypeVar("_M")

class DataLink(proto.Message):
    resource_name: str
    product_link_id: int
    data_link_id: int
    type_: DataLinkTypeEnum.DataLinkType
    status: DataLinkStatusEnum.DataLinkStatus
    youtube_video: YoutubeVideoIdentifier
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        product_link_id: int = ...,
        data_link_id: int = ...,
        type_: DataLinkTypeEnum.DataLinkType = ...,
        status: DataLinkStatusEnum.DataLinkStatus = ...,
        youtube_video: YoutubeVideoIdentifier = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "resource_name",
            "product_link_id",
            "data_link_id",
            "type_",
            "status",
            "youtube_video",
        ],
    ) -> bool: ...

class YoutubeVideoIdentifier(proto.Message):
    channel_id: str
    video_id: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        channel_id: str = ...,
        video_id: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["channel_id", "video_id"]
    ) -> bool: ...



from .async_client import (
    CustomerNegativeCriterionServiceAsyncClient as CustomerNegativeCriterionServiceAsyncClient,
)
from .client import (
    CustomerNegativeCriterionServiceClient as CustomerNegativeCriterionServiceClient,
)

__all__ = [
    "CustomerNegativeCriterionServiceClient",
    "CustomerNegativeCriterionServiceAsyncClient",
]



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v22.common.types.criteria import KeywordInfo
from google.ads.googleads.v22.enums.types.ad_destination_type import (
    AdDestinationTypeEnum,
)
from google.ads.googleads.v22.enums.types.ad_format_type import AdFormatTypeEnum
from google.ads.googleads.v22.enums.types.ad_network_type import AdNetworkTypeEnum
from google.ads.googleads.v22.enums.types.age_range_type import AgeRangeTypeEnum
from google.ads.googleads.v22.enums.types.budget_campaign_association_status import (
    BudgetCampaignAssociationStatusEnum,
)
from google.ads.googleads.v22.enums.types.click_type import ClickTypeEnum
from google.ads.googleads.v22.enums.types.conversion_action_category import (
    ConversionActionCategoryEnum,
)
from google.ads.googleads.v22.enums.types.conversion_attribution_event_type import (
    ConversionAttributionEventTypeEnum,
)
from google.ads.googleads.v22.enums.types.conversion_lag_bucket import (
    ConversionLagBucketEnum,
)
from google.ads.googleads.v22.enums.types.conversion_or_adjustment_lag_bucket import (
    ConversionOrAdjustmentLagBucketEnum,
)
from google.ads.googleads.v22.enums.types.conversion_value_rule_primary_dimension import (
    ConversionValueRulePrimaryDimensionEnum,
)
from google.ads.googleads.v22.enums.types.converting_user_prior_engagement_type_and_ltv_bucket import (
    ConvertingUserPriorEngagementTypeAndLtvBucketEnum,
)
from google.ads.googleads.v22.enums.types.day_of_week import DayOfWeekEnum
from google.ads.googleads.v22.enums.types.device import DeviceEnum
from google.ads.googleads.v22.enums.types.external_conversion_source import (
    ExternalConversionSourceEnum,
)
from google.ads.googleads.v22.enums.types.gender_type import GenderTypeEnum
from google.ads.googleads.v22.enums.types.hotel_date_selection_type import (
    HotelDateSelectionTypeEnum,
)
from google.ads.googleads.v22.enums.types.hotel_price_bucket import HotelPriceBucketEnum
from google.ads.googleads.v22.enums.types.hotel_rate_type import HotelRateTypeEnum
from google.ads.googleads.v22.enums.types.landing_page_source import (
    LandingPageSourceEnum,
)
from google.ads.googleads.v22.enums.types.match_type import MatchTypeEnum
from google.ads.googleads.v22.enums.types.month_of_year import MonthOfYearEnum
from google.ads.googleads.v22.enums.types.product_channel import ProductChannelEnum
from google.ads.googleads.v22.enums.types.product_channel_exclusivity import (
    ProductChannelExclusivityEnum,
)
from google.ads.googleads.v22.enums.types.product_condition import ProductConditionEnum
from google.ads.googleads.v22.enums.types.recommendation_type import (
    RecommendationTypeEnum,
)
from google.ads.googleads.v22.enums.types.search_engine_results_page_type import (
    SearchEngineResultsPageTypeEnum,
)
from google.ads.googleads.v22.enums.types.search_term_match_source import (
    SearchTermMatchSourceEnum,
)
from google.ads.googleads.v22.enums.types.search_term_match_type import (
    SearchTermMatchTypeEnum,
)
from google.ads.googleads.v22.enums.types.search_term_targeting_status import (
    SearchTermTargetingStatusEnum,
)
from google.ads.googleads.v22.enums.types.sk_ad_network_ad_event_type import (
    SkAdNetworkAdEventTypeEnum,
)
from google.ads.googleads.v22.enums.types.sk_ad_network_attribution_credit import (
    SkAdNetworkAttributionCreditEnum,
)
from google.ads.googleads.v22.enums.types.sk_ad_network_coarse_conversion_value import (
    SkAdNetworkCoarseConversionValueEnum,
)
from google.ads.googleads.v22.enums.types.sk_ad_network_source_type import (
    SkAdNetworkSourceTypeEnum,
)
from google.ads.googleads.v22.enums.types.sk_ad_network_user_type import (
    SkAdNetworkUserTypeEnum,
)
from google.ads.googleads.v22.enums.types.slot import SlotEnum

_M = TypeVar("_M")

class AssetInteractionTarget(proto.Message):
    asset: str
    interaction_on_this_asset: bool
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        asset: str = ...,
        interaction_on_this_asset: bool = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["asset", "interaction_on_this_asset"]
    ) -> bool: ...

class BudgetCampaignAssociationStatus(proto.Message):
    campaign: str
    status: BudgetCampaignAssociationStatusEnum.BudgetCampaignAssociationStatus
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        campaign: str = ...,
        status: BudgetCampaignAssociationStatusEnum.BudgetCampaignAssociationStatus = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["campaign", "status"]
    ) -> bool: ...

class Keyword(proto.Message):
    ad_group_criterion: str
    info: KeywordInfo
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        ad_group_criterion: str = ...,
        info: KeywordInfo = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["ad_group_criterion", "info"]
    ) -> bool: ...

class Segments(proto.Message):
    activity_account_id: int
    activity_city: str
    activity_country: str
    activity_rating: int
    activity_state: str
    external_activity_id: str
    ad_destination_type: AdDestinationTypeEnum.AdDestinationType
    ad_format_type: AdFormatTypeEnum.AdFormatType
    ad_network_type: AdNetworkTypeEnum.AdNetworkType
    ad_group: str
    asset_group: str
    auction_insight_domain: str
    budget_campaign_association_status: BudgetCampaignAssociationStatus
    campaign: str
    click_type: ClickTypeEnum.ClickType
    conversion_action: str
    conversion_action_category: ConversionActionCategoryEnum.ConversionActionCategory
    conversion_action_name: str
    conversion_adjustment: bool
    conversion_attribution_event_type: (
        ConversionAttributionEventTypeEnum.ConversionAttributionEventType
    )
    conversion_lag_bucket: ConversionLagBucketEnum.ConversionLagBucket
    conversion_or_adjustment_lag_bucket: (
        ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket
    )
    date: str
    day_of_week: DayOfWeekEnum.DayOfWeek
    device: DeviceEnum.Device
    external_conversion_source: ExternalConversionSourceEnum.ExternalConversionSource
    geo_target_airport: str
    geo_target_canton: str
    geo_target_city: str
    geo_target_country: str
    geo_target_county: str
    geo_target_district: str
    geo_target_metro: str
    geo_target_most_specific_location: str
    geo_target_postal_code: str
    geo_target_province: str
    geo_target_region: str
    geo_target_state: str
    hotel_booking_window_days: int
    hotel_center_id: int
    hotel_check_in_date: str
    hotel_check_in_day_of_week: DayOfWeekEnum.DayOfWeek
    hotel_city: str
    hotel_class: int
    hotel_country: str
    hotel_date_selection_type: HotelDateSelectionTypeEnum.HotelDateSelectionType
    hotel_length_of_stay: int
    hotel_rate_rule_id: str
    hotel_rate_type: HotelRateTypeEnum.HotelRateType
    hotel_price_bucket: HotelPriceBucketEnum.HotelPriceBucket
    hotel_state: str
    hour: int
    interaction_on_this_extension: bool
    keyword: Keyword
    landing_page_source: LandingPageSourceEnum.LandingPageSource
    month: str
    month_of_year: MonthOfYearEnum.MonthOfYear
    partner_hotel_id: str
    product_aggregator_id: int
    product_category_level1: str
    product_category_level2: str
    product_category_level3: str
    product_category_level4: str
    product_category_level5: str
    product_brand: str
    product_channel: ProductChannelEnum.ProductChannel
    product_channel_exclusivity: ProductChannelExclusivityEnum.ProductChannelExclusivity
    product_condition: ProductConditionEnum.ProductCondition
    product_country: str
    product_custom_attribute0: str
    product_custom_attribute1: str
    product_custom_attribute2: str
    product_custom_attribute3: str
    product_custom_attribute4: str
    product_feed_label: str
    product_item_id: str
    product_language: str
    product_merchant_id: int
    product_store_id: str
    product_title: str
    product_type_l1: str
    product_type_l2: str
    product_type_l3: str
    product_type_l4: str
    product_type_l5: str
    quarter: str
    travel_destination_city: str
    travel_destination_country: str
    travel_destination_region: str
    recommendation_type: RecommendationTypeEnum.RecommendationType
    search_engine_results_page_type: (
        SearchEngineResultsPageTypeEnum.SearchEngineResultsPageType
    )
    search_subcategory: str
    search_term: str
    search_term_match_type: SearchTermMatchTypeEnum.SearchTermMatchType
    match_type: MatchTypeEnum.MatchType
    slot: SlotEnum.Slot
    conversion_value_rule_primary_dimension: (
        ConversionValueRulePrimaryDimensionEnum.ConversionValueRulePrimaryDimension
    )
    webpage: str
    week: str
    year: int
    sk_ad_network_fine_conversion_value: int
    sk_ad_network_redistributed_fine_conversion_value: int
    sk_ad_network_user_type: SkAdNetworkUserTypeEnum.SkAdNetworkUserType
    sk_ad_network_ad_event_type: SkAdNetworkAdEventTypeEnum.SkAdNetworkAdEventType
    sk_ad_network_source_app: SkAdNetworkSourceApp
    sk_ad_network_attribution_credit: (
        SkAdNetworkAttributionCreditEnum.SkAdNetworkAttributionCredit
    )
    sk_ad_network_coarse_conversion_value: (
        SkAdNetworkCoarseConversionValueEnum.SkAdNetworkCoarseConversionValue
    )
    sk_ad_network_source_domain: str
    sk_ad_network_source_type: SkAdNetworkSourceTypeEnum.SkAdNetworkSourceType
    sk_ad_network_postback_sequence_index: int
    sk_ad_network_version: str
    asset_interaction_target: AssetInteractionTarget
    new_versus_returning_customers: ConvertingUserPriorEngagementTypeAndLtvBucketEnum.ConvertingUserPriorEngagementTypeAndLtvBucket
    adjusted_age_range: AgeRangeTypeEnum.AgeRangeType
    adjusted_gender: GenderTypeEnum.GenderType
    search_term_match_source: SearchTermMatchSourceEnum.SearchTermMatchSource
    search_term_targeting_status: (
        SearchTermTargetingStatusEnum.SearchTermTargetingStatus
    )
    ad_using_product_data: bool
    ad_using_video: bool
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        activity_account_id: int = ...,
        activity_city: str = ...,
        activity_country: str = ...,
        activity_rating: int = ...,
        activity_state: str = ...,
        external_activity_id: str = ...,
        ad_destination_type: AdDestinationTypeEnum.AdDestinationType = ...,
        ad_format_type: AdFormatTypeEnum.AdFormatType = ...,
        ad_network_type: AdNetworkTypeEnum.AdNetworkType = ...,
        ad_group: str = ...,
        asset_group: str = ...,
        auction_insight_domain: str = ...,
        budget_campaign_association_status: BudgetCampaignAssociationStatus = ...,
        campaign: str = ...,
        click_type: ClickTypeEnum.ClickType = ...,
        conversion_action: str = ...,
        conversion_action_category: ConversionActionCategoryEnum.ConversionActionCategory = ...,
        conversion_action_name: str = ...,
        conversion_adjustment: bool = ...,
        conversion_attribution_event_type: ConversionAttributionEventTypeEnum.ConversionAttributionEventType = ...,
        conversion_lag_bucket: ConversionLagBucketEnum.ConversionLagBucket = ...,
        conversion_or_adjustment_lag_bucket: ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket = ...,
        date: str = ...,
        day_of_week: DayOfWeekEnum.DayOfWeek = ...,
        device: DeviceEnum.Device = ...,
        external_conversion_source: ExternalConversionSourceEnum.ExternalConversionSource = ...,
        geo_target_airport: str = ...,
        geo_target_canton: str = ...,
        geo_target_city: str = ...,
        geo_target_country: str = ...,
        geo_target_county: str = ...,
        geo_target_district: str = ...,
        geo_target_metro: str = ...,
        geo_target_most_specific_location: str = ...,
        geo_target_postal_code: str = ...,
        geo_target_province: str = ...,
        geo_target_region: str = ...,
        geo_target_state: str = ...,
        hotel_booking_window_days: int = ...,
        hotel_center_id: int = ...,
        hotel_check_in_date: str = ...,
        hotel_check_in_day_of_week: DayOfWeekEnum.DayOfWeek = ...,
        hotel_city: str = ...,
        hotel_class: int = ...,
        hotel_country: str = ...,
        hotel_date_selection_type: HotelDateSelectionTypeEnum.HotelDateSelectionType = ...,
        hotel_length_of_stay: int = ...,
        hotel_rate_rule_id: str = ...,
        hotel_rate_type: HotelRateTypeEnum.HotelRateType = ...,
        hotel_price_bucket: HotelPriceBucketEnum.HotelPriceBucket = ...,
        hotel_state: str = ...,
        hour: int = ...,
        interaction_on_this_extension: bool = ...,
        keyword: Keyword = ...,
        landing_page_source: LandingPageSourceEnum.LandingPageSource = ...,
        month: str = ...,
        month_of_year: MonthOfYearEnum.MonthOfYear = ...,
        partner_hotel_id: str = ...,
        product_aggregator_id: int = ...,
        product_category_level1: str = ...,
        product_category_level2: str = ...,
        product_category_level3: str = ...,
        product_category_level4: str = ...,
        product_category_level5: str = ...,
        product_brand: str = ...,
        product_channel: ProductChannelEnum.ProductChannel = ...,
        product_channel_exclusivity: ProductChannelExclusivityEnum.ProductChannelExclusivity = ...,
        product_condition: ProductConditionEnum.ProductCondition = ...,
        product_country: str = ...,
        product_custom_attribute0: str = ...,
        product_custom_attribute1: str = ...,
        product_custom_attribute2: str = ...,
        product_custom_attribute3: str = ...,
        product_custom_attribute4: str = ...,
        product_feed_label: str = ...,
        product_item_id: str = ...,
        product_language: str = ...,
        product_merchant_id: int = ...,
        product_store_id: str = ...,
        product_title: str = ...,
        product_type_l1: str = ...,
        product_type_l2: str = ...,
        product_type_l3: str = ...,
        product_type_l4: str = ...,
        product_type_l5: str = ...,
        quarter: str = ...,
        travel_destination_city: str = ...,
        travel_destination_country: str = ...,
        travel_destination_region: str = ...,
        recommendation_type: RecommendationTypeEnum.RecommendationType = ...,
        search_engine_results_page_type: SearchEngineResultsPageTypeEnum.SearchEngineResultsPageType = ...,
        search_subcategory: str = ...,
        search_term: str = ...,
        search_term_match_type: SearchTermMatchTypeEnum.SearchTermMatchType = ...,
        match_type: MatchTypeEnum.MatchType = ...,
        slot: SlotEnum.Slot = ...,
        conversion_value_rule_primary_dimension: ConversionValueRulePrimaryDimensionEnum.ConversionValueRulePrimaryDimension = ...,
        webpage: str = ...,
        week: str = ...,
        year: int = ...,
        sk_ad_network_fine_conversion_value: int = ...,
        sk_ad_network_redistributed_fine_conversion_value: int = ...,
        sk_ad_network_user_type: SkAdNetworkUserTypeEnum.SkAdNetworkUserType = ...,
        sk_ad_network_ad_event_type: SkAdNetworkAdEventTypeEnum.SkAdNetworkAdEventType = ...,
        sk_ad_network_source_app: SkAdNetworkSourceApp = ...,
        sk_ad_network_attribution_credit: SkAdNetworkAttributionCreditEnum.SkAdNetworkAttributionCredit = ...,
        sk_ad_network_coarse_conversion_value: SkAdNetworkCoarseConversionValueEnum.SkAdNetworkCoarseConversionValue = ...,
        sk_ad_network_source_domain: str = ...,
        sk_ad_network_source_type: SkAdNetworkSourceTypeEnum.SkAdNetworkSourceType = ...,
        sk_ad_network_postback_sequence_index: int = ...,
        sk_ad_network_version: str = ...,
        asset_interaction_target: AssetInteractionTarget = ...,
        new_versus_returning_customers: ConvertingUserPriorEngagementTypeAndLtvBucketEnum.ConvertingUserPriorEngagementTypeAndLtvBucket = ...,
        adjusted_age_range: AgeRangeTypeEnum.AgeRangeType = ...,
        adjusted_gender: GenderTypeEnum.GenderType = ...,
        search_term_match_source: SearchTermMatchSourceEnum.SearchTermMatchSource = ...,
        search_term_targeting_status: SearchTermTargetingStatusEnum.SearchTermTargetingStatus = ...,
        ad_using_product_data: bool = ...,
        ad_using_video: bool = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "activity_account_id",
            "activity_city",
            "activity_country",
            "activity_rating",
            "activity_state",
            "external_activity_id",
            "ad_destination_type",
            "ad_format_type",
            "ad_network_type",
            "ad_group",
            "asset_group",
            "auction_insight_domain",
            "budget_campaign_association_status",
            "campaign",
            "click_type",
            "conversion_action",
            "conversion_action_category",
            "conversion_action_name",
            "conversion_adjustment",
            "conversion_attribution_event_type",
            "conversion_lag_bucket",
            "conversion_or_adjustment_lag_bucket",
            "date",
            "day_of_week",
            "device",
            "external_conversion_source",
            "geo_target_airport",
            "geo_target_canton",
            "geo_target_city",
            "geo_target_country",
            "geo_target_county",
            "geo_target_district",
            "geo_target_metro",
            "geo_target_most_specific_location",
            "geo_target_postal_code",
            "geo_target_province",
            "geo_target_region",
            "geo_target_state",
            "hotel_booking_window_days",
            "hotel_center_id",
            "hotel_check_in_date",
            "hotel_check_in_day_of_week",
            "hotel_city",
            "hotel_class",
            "hotel_country",
            "hotel_date_selection_type",
            "hotel_length_of_stay",
            "hotel_rate_rule_id",
            "hotel_rate_type",
            "hotel_price_bucket",
            "hotel_state",
            "hour",
            "interaction_on_this_extension",
            "keyword",
            "landing_page_source",
            "month",
            "month_of_year",
            "partner_hotel_id",
            "product_aggregator_id",
            "product_category_level1",
            "product_category_level2",
            "product_category_level3",
            "product_category_level4",
            "product_category_level5",
            "product_brand",
            "product_channel",
            "product_channel_exclusivity",
            "product_condition",
            "product_country",
            "product_custom_attribute0",
            "product_custom_attribute1",
            "product_custom_attribute2",
            "product_custom_attribute3",
            "product_custom_attribute4",
            "product_feed_label",
            "product_item_id",
            "product_language",
            "product_merchant_id",
            "product_store_id",
            "product_title",
            "product_type_l1",
            "product_type_l2",
            "product_type_l3",
            "product_type_l4",
            "product_type_l5",
            "quarter",
            "travel_destination_city",
            "travel_destination_country",
            "travel_destination_region",
            "recommendation_type",
            "search_engine_results_page_type",
            "search_subcategory",
            "search_term",
            "search_term_match_type",
            "match_type",
            "slot",
            "conversion_value_rule_primary_dimension",
            "webpage",
            "week",
            "year",
            "sk_ad_network_fine_conversion_value",
            "sk_ad_network_redistributed_fine_conversion_value",
            "sk_ad_network_user_type",
            "sk_ad_network_ad_event_type",
            "sk_ad_network_source_app",
            "sk_ad_network_attribution_credit",
            "sk_ad_network_coarse_conversion_value",
            "sk_ad_network_source_domain",
            "sk_ad_network_source_type",
            "sk_ad_network_postback_sequence_index",
            "sk_ad_network_version",
            "asset_interaction_target",
            "new_versus_returning_customers",
            "adjusted_age_range",
            "adjusted_gender",
            "search_term_match_source",
            "search_term_targeting_status",
            "ad_using_product_data",
            "ad_using_video",
        ],
    ) -> bool: ...

class SkAdNetworkSourceApp(proto.Message):
    sk_ad_network_source_app_id: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        sk_ad_network_source_app_id: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["sk_ad_network_source_app_id"]
    ) -> bool: ...



from .base import AdGroupServiceTransport as AdGroupServiceTransport
from .grpc import AdGroupServiceGrpcTransport as AdGroupServiceGrpcTransport
from .grpc_asyncio import (
    AdGroupServiceGrpcAsyncIOTransport as AdGroupServiceGrpcAsyncIOTransport,
)

__all__ = [
    "AdGroupServiceTransport",
    "AdGroupServiceGrpcTransport",
    "AdGroupServiceGrpcAsyncIOTransport",
]



from .async_client import (
    CampaignAssetServiceAsyncClient as CampaignAssetServiceAsyncClient,
)
from .client import CampaignAssetServiceClient as CampaignAssetServiceClient

__all__ = ["CampaignAssetServiceClient", "CampaignAssetServiceAsyncClient"]



from .async_client import (
    ConversionActionServiceAsyncClient as ConversionActionServiceAsyncClient,
)
from .client import ConversionActionServiceClient as ConversionActionServiceClient

__all__ = ["ConversionActionServiceClient", "ConversionActionServiceAsyncClient"]



from .base import CampaignServiceTransport as CampaignServiceTransport
from .grpc import CampaignServiceGrpcTransport as CampaignServiceGrpcTransport
from .grpc_asyncio import (
    CampaignServiceGrpcAsyncIOTransport as CampaignServiceGrpcAsyncIOTransport,
)

__all__ = [
    "CampaignServiceTransport",
    "CampaignServiceGrpcTransport",
    "CampaignServiceGrpcAsyncIOTransport",
]



from .async_client import AudienceServiceAsyncClient as AudienceServiceAsyncClient
from .client import AudienceServiceClient as AudienceServiceClient

__all__ = ["AudienceServiceClient", "AudienceServiceAsyncClient"]



from .types.access_invitation_error import (
    AccessInvitationErrorEnum as AccessInvitationErrorEnum,
)
from .types.account_budget_proposal_error import (
    AccountBudgetProposalErrorEnum as AccountBudgetProposalErrorEnum,
)
from .types.account_link_error import AccountLinkErrorEnum as AccountLinkErrorEnum
from .types.ad_customizer_error import AdCustomizerErrorEnum as AdCustomizerErrorEnum
from .types.ad_error import AdErrorEnum as AdErrorEnum
from .types.ad_group_ad_error import AdGroupAdErrorEnum as AdGroupAdErrorEnum
from .types.ad_group_bid_modifier_error import (
    AdGroupBidModifierErrorEnum as AdGroupBidModifierErrorEnum,
)
from .types.ad_group_criterion_customizer_error import (
    AdGroupCriterionCustomizerErrorEnum as AdGroupCriterionCustomizerErrorEnum,
)
from .types.ad_group_criterion_error import (
    AdGroupCriterionErrorEnum as AdGroupCriterionErrorEnum,
)
from .types.ad_group_customizer_error import (
    AdGroupCustomizerErrorEnum as AdGroupCustomizerErrorEnum,
)
from .types.ad_group_error import AdGroupErrorEnum as AdGroupErrorEnum
from .types.ad_group_feed_error import AdGroupFeedErrorEnum as AdGroupFeedErrorEnum
from .types.ad_parameter_error import AdParameterErrorEnum as AdParameterErrorEnum
from .types.ad_sharing_error import AdSharingErrorEnum as AdSharingErrorEnum
from .types.adx_error import AdxErrorEnum as AdxErrorEnum
from .types.asset_error import AssetErrorEnum as AssetErrorEnum
from .types.asset_group_asset_error import (
    AssetGroupAssetErrorEnum as AssetGroupAssetErrorEnum,
)
from .types.asset_group_error import AssetGroupErrorEnum as AssetGroupErrorEnum
from .types.asset_group_listing_group_filter_error import (
    AssetGroupListingGroupFilterErrorEnum as AssetGroupListingGroupFilterErrorEnum,
)
from .types.asset_group_signal_error import (
    AssetGroupSignalErrorEnum as AssetGroupSignalErrorEnum,
)
from .types.asset_link_error import AssetLinkErrorEnum as AssetLinkErrorEnum
from .types.asset_set_asset_error import (
    AssetSetAssetErrorEnum as AssetSetAssetErrorEnum,
)
from .types.asset_set_error import AssetSetErrorEnum as AssetSetErrorEnum
from .types.asset_set_link_error import AssetSetLinkErrorEnum as AssetSetLinkErrorEnum
from .types.audience_error import AudienceErrorEnum as AudienceErrorEnum
from .types.audience_insights_error import (
    AudienceInsightsErrorEnum as AudienceInsightsErrorEnum,
)
from .types.authentication_error import (
    AuthenticationErrorEnum as AuthenticationErrorEnum,
)
from .types.authorization_error import AuthorizationErrorEnum as AuthorizationErrorEnum
from .types.automatically_created_asset_removal_error import (
    AutomaticallyCreatedAssetRemovalErrorEnum as AutomaticallyCreatedAssetRemovalErrorEnum,
)
from .types.batch_job_error import BatchJobErrorEnum as BatchJobErrorEnum
from .types.bidding_error import BiddingErrorEnum as BiddingErrorEnum
from .types.bidding_strategy_error import (
    BiddingStrategyErrorEnum as BiddingStrategyErrorEnum,
)
from .types.billing_setup_error import BillingSetupErrorEnum as BillingSetupErrorEnum
from .types.brand_guidelines_migration_error import (
    BrandGuidelinesMigrationErrorEnum as BrandGuidelinesMigrationErrorEnum,
)
from .types.campaign_budget_error import (
    CampaignBudgetErrorEnum as CampaignBudgetErrorEnum,
)
from .types.campaign_conversion_goal_error import (
    CampaignConversionGoalErrorEnum as CampaignConversionGoalErrorEnum,
)
from .types.campaign_criterion_error import (
    CampaignCriterionErrorEnum as CampaignCriterionErrorEnum,
)
from .types.campaign_customizer_error import (
    CampaignCustomizerErrorEnum as CampaignCustomizerErrorEnum,
)
from .types.campaign_draft_error import CampaignDraftErrorEnum as CampaignDraftErrorEnum
from .types.campaign_error import CampaignErrorEnum as CampaignErrorEnum
from .types.campaign_experiment_error import (
    CampaignExperimentErrorEnum as CampaignExperimentErrorEnum,
)
from .types.campaign_feed_error import CampaignFeedErrorEnum as CampaignFeedErrorEnum
from .types.campaign_lifecycle_goal_error import (
    CampaignLifecycleGoalErrorEnum as CampaignLifecycleGoalErrorEnum,
)
from .types.campaign_shared_set_error import (
    CampaignSharedSetErrorEnum as CampaignSharedSetErrorEnum,
)
from .types.change_event_error import ChangeEventErrorEnum as ChangeEventErrorEnum
from .types.change_status_error import ChangeStatusErrorEnum as ChangeStatusErrorEnum
from .types.collection_size_error import (
    CollectionSizeErrorEnum as CollectionSizeErrorEnum,
)
from .types.context_error import ContextErrorEnum as ContextErrorEnum
from .types.conversion_action_error import (
    ConversionActionErrorEnum as ConversionActionErrorEnum,
)
from .types.conversion_adjustment_upload_error import (
    ConversionAdjustmentUploadErrorEnum as ConversionAdjustmentUploadErrorEnum,
)
from .types.conversion_custom_variable_error import (
    ConversionCustomVariableErrorEnum as ConversionCustomVariableErrorEnum,
)
from .types.conversion_goal_campaign_config_error import (
    ConversionGoalCampaignConfigErrorEnum as ConversionGoalCampaignConfigErrorEnum,
)
from .types.conversion_upload_error import (
    ConversionUploadErrorEnum as ConversionUploadErrorEnum,
)
from .types.conversion_value_rule_error import (
    ConversionValueRuleErrorEnum as ConversionValueRuleErrorEnum,
)
from .types.conversion_value_rule_set_error import (
    ConversionValueRuleSetErrorEnum as ConversionValueRuleSetErrorEnum,
)
from .types.country_code_error import CountryCodeErrorEnum as CountryCodeErrorEnum
from .types.criterion_error import CriterionErrorEnum as CriterionErrorEnum
from .types.currency_code_error import CurrencyCodeErrorEnum as CurrencyCodeErrorEnum
from .types.currency_error import CurrencyErrorEnum as CurrencyErrorEnum
from .types.custom_audience_error import (
    CustomAudienceErrorEnum as CustomAudienceErrorEnum,
)
from .types.custom_conversion_goal_error import (
    CustomConversionGoalErrorEnum as CustomConversionGoalErrorEnum,
)
from .types.custom_interest_error import (
    CustomInterestErrorEnum as CustomInterestErrorEnum,
)
from .types.customer_client_link_error import (
    CustomerClientLinkErrorEnum as CustomerClientLinkErrorEnum,
)
from .types.customer_customizer_error import (
    CustomerCustomizerErrorEnum as CustomerCustomizerErrorEnum,
)
from .types.customer_error import CustomerErrorEnum as CustomerErrorEnum
from .types.customer_feed_error import CustomerFeedErrorEnum as CustomerFeedErrorEnum
from .types.customer_lifecycle_goal_error import (
    CustomerLifecycleGoalErrorEnum as CustomerLifecycleGoalErrorEnum,
)
from .types.customer_manager_link_error import (
    CustomerManagerLinkErrorEnum as CustomerManagerLinkErrorEnum,
)
from .types.customer_sk_ad_network_conversion_value_schema_error import (
    CustomerSkAdNetworkConversionValueSchemaErrorEnum as CustomerSkAdNetworkConversionValueSchemaErrorEnum,
)
from .types.customer_user_access_error import (
    CustomerUserAccessErrorEnum as CustomerUserAccessErrorEnum,
)
from .types.customizer_attribute_error import (
    CustomizerAttributeErrorEnum as CustomizerAttributeErrorEnum,
)
from .types.data_link_error import DataLinkErrorEnum as DataLinkErrorEnum
from .types.database_error import DatabaseErrorEnum as DatabaseErrorEnum
from .types.date_error import DateErrorEnum as DateErrorEnum
from .types.date_range_error import DateRangeErrorEnum as DateRangeErrorEnum
from .types.distinct_error import DistinctErrorEnum as DistinctErrorEnum
from .types.enum_error import EnumErrorEnum as EnumErrorEnum
from .types.errors import (
    ErrorCode as ErrorCode,
    ErrorDetails as ErrorDetails,
    ErrorLocation as ErrorLocation,
    GoogleAdsError as GoogleAdsError,
    GoogleAdsFailure as GoogleAdsFailure,
    PolicyFindingDetails as PolicyFindingDetails,
    PolicyViolationDetails as PolicyViolationDetails,
    QuotaErrorDetails as QuotaErrorDetails,
    ResourceCountDetails as ResourceCountDetails,
)
from .types.experiment_arm_error import ExperimentArmErrorEnum as ExperimentArmErrorEnum
from .types.experiment_error import ExperimentErrorEnum as ExperimentErrorEnum
from .types.extension_feed_item_error import (
    ExtensionFeedItemErrorEnum as ExtensionFeedItemErrorEnum,
)
from .types.extension_setting_error import (
    ExtensionSettingErrorEnum as ExtensionSettingErrorEnum,
)
from .types.feed_attribute_reference_error import (
    FeedAttributeReferenceErrorEnum as FeedAttributeReferenceErrorEnum,
)
from .types.feed_error import FeedErrorEnum as FeedErrorEnum
from .types.feed_item_error import FeedItemErrorEnum as FeedItemErrorEnum
from .types.feed_item_set_error import FeedItemSetErrorEnum as FeedItemSetErrorEnum
from .types.feed_item_set_link_error import (
    FeedItemSetLinkErrorEnum as FeedItemSetLinkErrorEnum,
)
from .types.feed_item_target_error import (
    FeedItemTargetErrorEnum as FeedItemTargetErrorEnum,
)
from .types.feed_item_validation_error import (
    FeedItemValidationErrorEnum as FeedItemValidationErrorEnum,
)
from .types.feed_mapping_error import FeedMappingErrorEnum as FeedMappingErrorEnum
from .types.field_error import FieldErrorEnum as FieldErrorEnum
from .types.field_mask_error import FieldMaskErrorEnum as FieldMaskErrorEnum
from .types.function_error import FunctionErrorEnum as FunctionErrorEnum
from .types.function_parsing_error import (
    FunctionParsingErrorEnum as FunctionParsingErrorEnum,
)
from .types.geo_target_constant_suggestion_error import (
    GeoTargetConstantSuggestionErrorEnum as GeoTargetConstantSuggestionErrorEnum,
)
from .types.header_error import HeaderErrorEnum as HeaderErrorEnum
from .types.id_error import IdErrorEnum as IdErrorEnum
from .types.identity_verification_error import (
    IdentityVerificationErrorEnum as IdentityVerificationErrorEnum,
)
from .types.image_error import ImageErrorEnum as ImageErrorEnum
from .types.internal_error import InternalErrorEnum as InternalErrorEnum
from .types.invoice_error import InvoiceErrorEnum as InvoiceErrorEnum
from .types.keyword_plan_ad_group_error import (
    KeywordPlanAdGroupErrorEnum as KeywordPlanAdGroupErrorEnum,
)
from .types.keyword_plan_ad_group_keyword_error import (
    KeywordPlanAdGroupKeywordErrorEnum as KeywordPlanAdGroupKeywordErrorEnum,
)
from .types.keyword_plan_campaign_error import (
    KeywordPlanCampaignErrorEnum as KeywordPlanCampaignErrorEnum,
)
from .types.keyword_plan_campaign_keyword_error import (
    KeywordPlanCampaignKeywordErrorEnum as KeywordPlanCampaignKeywordErrorEnum,
)
from .types.keyword_plan_error import KeywordPlanErrorEnum as KeywordPlanErrorEnum
from .types.keyword_plan_idea_error import (
    KeywordPlanIdeaErrorEnum as KeywordPlanIdeaErrorEnum,
)
from .types.label_error import LabelErrorEnum as LabelErrorEnum
from .types.language_code_error import LanguageCodeErrorEnum as LanguageCodeErrorEnum
from .types.list_operation_error import ListOperationErrorEnum as ListOperationErrorEnum
from .types.manager_link_error import ManagerLinkErrorEnum as ManagerLinkErrorEnum
from .types.media_bundle_error import MediaBundleErrorEnum as MediaBundleErrorEnum
from .types.media_file_error import MediaFileErrorEnum as MediaFileErrorEnum
from .types.media_upload_error import MediaUploadErrorEnum as MediaUploadErrorEnum
from .types.merchant_center_error import (
    MerchantCenterErrorEnum as MerchantCenterErrorEnum,
)
from .types.multiplier_error import MultiplierErrorEnum as MultiplierErrorEnum
from .types.mutate_error import MutateErrorEnum as MutateErrorEnum
from .types.new_resource_creation_error import (
    NewResourceCreationErrorEnum as NewResourceCreationErrorEnum,
)
from .types.not_allowlisted_error import (
    NotAllowlistedErrorEnum as NotAllowlistedErrorEnum,
)
from .types.not_empty_error import NotEmptyErrorEnum as NotEmptyErrorEnum
from .types.null_error import NullErrorEnum as NullErrorEnum
from .types.offline_user_data_job_error import (
    OfflineUserDataJobErrorEnum as OfflineUserDataJobErrorEnum,
)
from .types.operation_access_denied_error import (
    OperationAccessDeniedErrorEnum as OperationAccessDeniedErrorEnum,
)
from .types.operator_error import OperatorErrorEnum as OperatorErrorEnum
from .types.partial_failure_error import (
    PartialFailureErrorEnum as PartialFailureErrorEnum,
)
from .types.payments_account_error import (
    PaymentsAccountErrorEnum as PaymentsAccountErrorEnum,
)
from .types.policy_finding_error import PolicyFindingErrorEnum as PolicyFindingErrorEnum
from .types.policy_validation_parameter_error import (
    PolicyValidationParameterErrorEnum as PolicyValidationParameterErrorEnum,
)
from .types.policy_violation_error import (
    PolicyViolationErrorEnum as PolicyViolationErrorEnum,
)
from .types.product_link_error import ProductLinkErrorEnum as ProductLinkErrorEnum
from .types.product_link_invitation_error import (
    ProductLinkInvitationErrorEnum as ProductLinkInvitationErrorEnum,
)
from .types.query_error import QueryErrorEnum as QueryErrorEnum
from .types.quota_error import QuotaErrorEnum as QuotaErrorEnum
from .types.range_error import RangeErrorEnum as RangeErrorEnum
from .types.reach_plan_error import ReachPlanErrorEnum as ReachPlanErrorEnum
from .types.recommendation_error import (
    RecommendationErrorEnum as RecommendationErrorEnum,
)
from .types.recommendation_subscription_error import (
    RecommendationSubscriptionErrorEnum as RecommendationSubscriptionErrorEnum,
)
from .types.region_code_error import RegionCodeErrorEnum as RegionCodeErrorEnum
from .types.request_error import RequestErrorEnum as RequestErrorEnum
from .types.resource_access_denied_error import (
    ResourceAccessDeniedErrorEnum as ResourceAccessDeniedErrorEnum,
)
from .types.resource_count_limit_exceeded_error import (
    ResourceCountLimitExceededErrorEnum as ResourceCountLimitExceededErrorEnum,
)
from .types.search_term_insight_error import (
    SearchTermInsightErrorEnum as SearchTermInsightErrorEnum,
)
from .types.setting_error import SettingErrorEnum as SettingErrorEnum
from .types.shareable_preview_error import (
    ShareablePreviewErrorEnum as ShareablePreviewErrorEnum,
)
from .types.shared_criterion_error import (
    SharedCriterionErrorEnum as SharedCriterionErrorEnum,
)
from .types.shared_set_error import SharedSetErrorEnum as SharedSetErrorEnum
from .types.shopping_product_error import (
    ShoppingProductErrorEnum as ShoppingProductErrorEnum,
)
from .types.size_limit_error import SizeLimitErrorEnum as SizeLimitErrorEnum
from .types.smart_campaign_error import SmartCampaignErrorEnum as SmartCampaignErrorEnum
from .types.string_format_error import StringFormatErrorEnum as StringFormatErrorEnum
from .types.string_length_error import StringLengthErrorEnum as StringLengthErrorEnum
from .types.third_party_app_analytics_link_error import (
    ThirdPartyAppAnalyticsLinkErrorEnum as ThirdPartyAppAnalyticsLinkErrorEnum,
)
from .types.time_zone_error import TimeZoneErrorEnum as TimeZoneErrorEnum
from .types.url_field_error import UrlFieldErrorEnum as UrlFieldErrorEnum
from .types.user_data_error import UserDataErrorEnum as UserDataErrorEnum
from .types.user_list_customer_type_error import (
    UserListCustomerTypeErrorEnum as UserListCustomerTypeErrorEnum,
)
from .types.user_list_error import UserListErrorEnum as UserListErrorEnum
from .types.video_campaign_error import VideoCampaignErrorEnum as VideoCampaignErrorEnum
from .types.youtube_video_registration_error import (
    YoutubeVideoRegistrationErrorEnum as YoutubeVideoRegistrationErrorEnum,
)

__all__ = [
    "AccessInvitationErrorEnum",
    "AccountBudgetProposalErrorEnum",
    "AccountLinkErrorEnum",
    "AdCustomizerErrorEnum",
    "AdErrorEnum",
    "AdGroupAdErrorEnum",
    "AdGroupBidModifierErrorEnum",
    "AdGroupCriterionCustomizerErrorEnum",
    "AdGroupCriterionErrorEnum",
    "AdGroupCustomizerErrorEnum",
    "AdGroupErrorEnum",
    "AdGroupFeedErrorEnum",
    "AdParameterErrorEnum",
    "AdSharingErrorEnum",
    "AdxErrorEnum",
    "AssetErrorEnum",
    "AssetGroupAssetErrorEnum",
    "AssetGroupErrorEnum",
    "AssetGroupListingGroupFilterErrorEnum",
    "AssetGroupSignalErrorEnum",
    "AssetLinkErrorEnum",
    "AssetSetAssetErrorEnum",
    "AssetSetErrorEnum",
    "AssetSetLinkErrorEnum",
    "AudienceErrorEnum",
    "AudienceInsightsErrorEnum",
    "AuthenticationErrorEnum",
    "AuthorizationErrorEnum",
    "AutomaticallyCreatedAssetRemovalErrorEnum",
    "BatchJobErrorEnum",
    "BiddingErrorEnum",
    "BiddingStrategyErrorEnum",
    "BillingSetupErrorEnum",
    "BrandGuidelinesMigrationErrorEnum",
    "CampaignBudgetErrorEnum",
    "CampaignConversionGoalErrorEnum",
    "CampaignCriterionErrorEnum",
    "CampaignCustomizerErrorEnum",
    "CampaignDraftErrorEnum",
    "CampaignErrorEnum",
    "CampaignExperimentErrorEnum",
    "CampaignFeedErrorEnum",
    "CampaignLifecycleGoalErrorEnum",
    "CampaignSharedSetErrorEnum",
    "ChangeEventErrorEnum",
    "ChangeStatusErrorEnum",
    "CollectionSizeErrorEnum",
    "ContextErrorEnum",
    "ConversionActionErrorEnum",
    "ConversionAdjustmentUploadErrorEnum",
    "ConversionCustomVariableErrorEnum",
    "ConversionGoalCampaignConfigErrorEnum",
    "ConversionUploadErrorEnum",
    "ConversionValueRuleErrorEnum",
    "ConversionValueRuleSetErrorEnum",
    "CountryCodeErrorEnum",
    "CriterionErrorEnum",
    "CurrencyCodeErrorEnum",
    "CurrencyErrorEnum",
    "CustomAudienceErrorEnum",
    "CustomConversionGoalErrorEnum",
    "CustomInterestErrorEnum",
    "CustomerClientLinkErrorEnum",
    "CustomerCustomizerErrorEnum",
    "CustomerErrorEnum",
    "CustomerFeedErrorEnum",
    "CustomerLifecycleGoalErrorEnum",
    "CustomerManagerLinkErrorEnum",
    "CustomerSkAdNetworkConversionValueSchemaErrorEnum",
    "CustomerUserAccessErrorEnum",
    "CustomizerAttributeErrorEnum",
    "DataLinkErrorEnum",
    "DatabaseErrorEnum",
    "DateErrorEnum",
    "DateRangeErrorEnum",
    "DistinctErrorEnum",
    "EnumErrorEnum",
    "ErrorCode",
    "ErrorDetails",
    "ErrorLocation",
    "ExperimentArmErrorEnum",
    "ExperimentErrorEnum",
    "ExtensionFeedItemErrorEnum",
    "ExtensionSettingErrorEnum",
    "FeedAttributeReferenceErrorEnum",
    "FeedErrorEnum",
    "FeedItemErrorEnum",
    "FeedItemSetErrorEnum",
    "FeedItemSetLinkErrorEnum",
    "FeedItemTargetErrorEnum",
    "FeedItemValidationErrorEnum",
    "FeedMappingErrorEnum",
    "FieldErrorEnum",
    "FieldMaskErrorEnum",
    "FunctionErrorEnum",
    "FunctionParsingErrorEnum",
    "GeoTargetConstantSuggestionErrorEnum",
    "GoogleAdsError",
    "GoogleAdsFailure",
    "HeaderErrorEnum",
    "IdErrorEnum",
    "IdentityVerificationErrorEnum",
    "ImageErrorEnum",
    "InternalErrorEnum",
    "InvoiceErrorEnum",
    "KeywordPlanAdGroupErrorEnum",
    "KeywordPlanAdGroupKeywordErrorEnum",
    "KeywordPlanCampaignErrorEnum",
    "KeywordPlanCampaignKeywordErrorEnum",
    "KeywordPlanErrorEnum",
    "KeywordPlanIdeaErrorEnum",
    "LabelErrorEnum",
    "LanguageCodeErrorEnum",
    "ListOperationErrorEnum",
    "ManagerLinkErrorEnum",
    "MediaBundleErrorEnum",
    "MediaFileErrorEnum",
    "MediaUploadErrorEnum",
    "MerchantCenterErrorEnum",
    "MultiplierErrorEnum",
    "MutateErrorEnum",
    "NewResourceCreationErrorEnum",
    "NotAllowlistedErrorEnum",
    "NotEmptyErrorEnum",
    "NullErrorEnum",
    "OfflineUserDataJobErrorEnum",
    "OperationAccessDeniedErrorEnum",
    "OperatorErrorEnum",
    "PartialFailureErrorEnum",
    "PaymentsAccountErrorEnum",
    "PolicyFindingDetails",
    "PolicyFindingErrorEnum",
    "PolicyValidationParameterErrorEnum",
    "PolicyViolationDetails",
    "PolicyViolationErrorEnum",
    "ProductLinkErrorEnum",
    "ProductLinkInvitationErrorEnum",
    "QueryErrorEnum",
    "QuotaErrorDetails",
    "QuotaErrorEnum",
    "RangeErrorEnum",
    "ReachPlanErrorEnum",
    "RecommendationErrorEnum",
    "RecommendationSubscriptionErrorEnum",
    "RegionCodeErrorEnum",
    "RequestErrorEnum",
    "ResourceAccessDeniedErrorEnum",
    "ResourceCountDetails",
    "ResourceCountLimitExceededErrorEnum",
    "SearchTermInsightErrorEnum",
    "SettingErrorEnum",
    "ShareablePreviewErrorEnum",
    "SharedCriterionErrorEnum",
    "SharedSetErrorEnum",
    "ShoppingProductErrorEnum",
    "SizeLimitErrorEnum",
    "SmartCampaignErrorEnum",
    "StringFormatErrorEnum",
    "StringLengthErrorEnum",
    "ThirdPartyAppAnalyticsLinkErrorEnum",
    "TimeZoneErrorEnum",
    "UrlFieldErrorEnum",
    "UserDataErrorEnum",
    "UserListCustomerTypeErrorEnum",
    "UserListErrorEnum",
    "VideoCampaignErrorEnum",
    "YoutubeVideoRegistrationErrorEnum",
]



from .async_client import AssetSetServiceAsyncClient as AssetSetServiceAsyncClient
from .client import AssetSetServiceClient as AssetSetServiceClient

__all__ = ["AssetSetServiceClient", "AssetSetServiceAsyncClient"]



from .async_client import (
    SmartCampaignSettingServiceAsyncClient as SmartCampaignSettingServiceAsyncClient,
)
from .client import (
    SmartCampaignSettingServiceClient as SmartCampaignSettingServiceClient,
)

__all__ = [
    "SmartCampaignSettingServiceClient",
    "SmartCampaignSettingServiceAsyncClient",
]



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from google.protobuf.field_mask_pb2 import FieldMask
from typing_extensions import Literal

from google.ads.googleads.v20.resources.types.campaign_lifecycle_goal import (
    CampaignLifecycleGoal,
)

_M = TypeVar("_M")

class CampaignLifecycleGoalOperation(proto.Message):
    update_mask: FieldMask
    create: CampaignLifecycleGoal
    update: CampaignLifecycleGoal
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        update_mask: FieldMask = ...,
        create: CampaignLifecycleGoal = ...,
        update: CampaignLifecycleGoal = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["update_mask", "create", "update"]
    ) -> bool: ...

class ConfigureCampaignLifecycleGoalsRequest(proto.Message):
    customer_id: str
    operation: CampaignLifecycleGoalOperation
    validate_only: bool
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        operation: CampaignLifecycleGoalOperation = ...,
        validate_only: bool = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["customer_id", "operation", "validate_only"]
    ) -> bool: ...

class ConfigureCampaignLifecycleGoalsResponse(proto.Message):
    result: ConfigureCampaignLifecycleGoalsResult
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        result: ConfigureCampaignLifecycleGoalsResult = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["result"]
    ) -> bool: ...

class ConfigureCampaignLifecycleGoalsResult(proto.Message):
    resource_name: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["resource_name"]
    ) -> bool: ...



from .async_client import BatchJobServiceAsyncClient as BatchJobServiceAsyncClient
from .client import BatchJobServiceClient as BatchJobServiceClient

__all__ = ["BatchJobServiceClient", "BatchJobServiceAsyncClient"]



from .base import (
    AssetGroupListingGroupFilterServiceTransport as AssetGroupListingGroupFilterServiceTransport,
)
from .grpc import (
    AssetGroupListingGroupFilterServiceGrpcTransport as AssetGroupListingGroupFilterServiceGrpcTransport,
)
from .grpc_asyncio import (
    AssetGroupListingGroupFilterServiceGrpcAsyncIOTransport as AssetGroupListingGroupFilterServiceGrpcAsyncIOTransport,
)

__all__ = [
    "AssetGroupListingGroupFilterServiceTransport",
    "AssetGroupListingGroupFilterServiceGrpcTransport",
    "AssetGroupListingGroupFilterServiceGrpcAsyncIOTransport",
]



from .base import AdGroupLabelServiceTransport as AdGroupLabelServiceTransport
from .grpc import AdGroupLabelServiceGrpcTransport as AdGroupLabelServiceGrpcTransport
from .grpc_asyncio import (
    AdGroupLabelServiceGrpcAsyncIOTransport as AdGroupLabelServiceGrpcAsyncIOTransport,
)

__all__ = [
    "AdGroupLabelServiceTransport",
    "AdGroupLabelServiceGrpcTransport",
    "AdGroupLabelServiceGrpcAsyncIOTransport",
]



from .async_client import KeywordPlanServiceAsyncClient as KeywordPlanServiceAsyncClient
from .client import KeywordPlanServiceClient as KeywordPlanServiceClient

__all__ = ["KeywordPlanServiceClient", "KeywordPlanServiceAsyncClient"]



from .async_client import InvoiceServiceAsyncClient as InvoiceServiceAsyncClient
from .client import InvoiceServiceClient as InvoiceServiceClient

__all__ = ["InvoiceServiceClient", "InvoiceServiceAsyncClient"]



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v21.resources.types.geo_target_constant import (
    GeoTargetConstant,
)

_M = TypeVar("_M")

class GeoTargetConstantSuggestion(proto.Message):
    locale: str
    reach: int
    search_term: str
    geo_target_constant: GeoTargetConstant
    geo_target_constant_parents: MutableSequence[GeoTargetConstant]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        locale: str = ...,
        reach: int = ...,
        search_term: str = ...,
        geo_target_constant: GeoTargetConstant = ...,
        geo_target_constant_parents: MutableSequence[GeoTargetConstant] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "locale",
            "reach",
            "search_term",
            "geo_target_constant",
            "geo_target_constant_parents",
        ],
    ) -> bool: ...

class SuggestGeoTargetConstantsRequest(proto.Message):
    class GeoTargets(proto.Message):
        geo_target_constants: MutableSequence[str]
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            geo_target_constants: MutableSequence[str] = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["geo_target_constants"]
        ) -> bool: ...

    class LocationNames(proto.Message):
        names: MutableSequence[str]
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            names: MutableSequence[str] = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["names"]
        ) -> bool: ...

    locale: str
    country_code: str
    location_names: SuggestGeoTargetConstantsRequest.LocationNames
    geo_targets: SuggestGeoTargetConstantsRequest.GeoTargets
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        locale: str = ...,
        country_code: str = ...,
        location_names: SuggestGeoTargetConstantsRequest.LocationNames = ...,
        geo_targets: SuggestGeoTargetConstantsRequest.GeoTargets = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["locale", "country_code", "location_names", "geo_targets"]
    ) -> bool: ...

class SuggestGeoTargetConstantsResponse(proto.Message):
    geo_target_constant_suggestions: MutableSequence[GeoTargetConstantSuggestion]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        geo_target_constant_suggestions: MutableSequence[
            GeoTargetConstantSuggestion
        ] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["geo_target_constant_suggestions"]
    ) -> bool: ...



from .async_client import (
    CustomerUserAccessInvitationServiceAsyncClient as CustomerUserAccessInvitationServiceAsyncClient,
)
from .client import (
    CustomerUserAccessInvitationServiceClient as CustomerUserAccessInvitationServiceClient,
)

__all__ = [
    "CustomerUserAccessInvitationServiceClient",
    "CustomerUserAccessInvitationServiceAsyncClient",
]



from .base import SharedCriterionServiceTransport as SharedCriterionServiceTransport
from .grpc import (
    SharedCriterionServiceGrpcTransport as SharedCriterionServiceGrpcTransport,
)
from .grpc_asyncio import (
    SharedCriterionServiceGrpcAsyncIOTransport as SharedCriterionServiceGrpcAsyncIOTransport,
)

__all__ = [
    "SharedCriterionServiceTransport",
    "SharedCriterionServiceGrpcTransport",
    "SharedCriterionServiceGrpcAsyncIOTransport",
]



from .async_client import (
    ExperimentArmServiceAsyncClient as ExperimentArmServiceAsyncClient,
)
from .client import ExperimentArmServiceClient as ExperimentArmServiceClient

__all__ = ["ExperimentArmServiceClient", "ExperimentArmServiceAsyncClient"]



from .async_client import (
    ConversionGoalCampaignConfigServiceAsyncClient as ConversionGoalCampaignConfigServiceAsyncClient,
)
from .client import (
    ConversionGoalCampaignConfigServiceClient as ConversionGoalCampaignConfigServiceClient,
)

__all__ = [
    "ConversionGoalCampaignConfigServiceClient",
    "ConversionGoalCampaignConfigServiceAsyncClient",
]



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v22.common.types.policy import PolicyTopicEntry
from google.ads.googleads.v22.enums.types.ad_group_ad_primary_status import (
    AdGroupAdPrimaryStatusEnum,
)
from google.ads.googleads.v22.enums.types.ad_group_ad_primary_status_reason import (
    AdGroupAdPrimaryStatusReasonEnum,
)
from google.ads.googleads.v22.enums.types.ad_group_ad_status import AdGroupAdStatusEnum
from google.ads.googleads.v22.enums.types.ad_strength import AdStrengthEnum
from google.ads.googleads.v22.enums.types.asset_automation_status import (
    AssetAutomationStatusEnum,
)
from google.ads.googleads.v22.enums.types.asset_automation_type import (
    AssetAutomationTypeEnum,
)
from google.ads.googleads.v22.enums.types.policy_approval_status import (
    PolicyApprovalStatusEnum,
)
from google.ads.googleads.v22.enums.types.policy_review_status import (
    PolicyReviewStatusEnum,
)
from google.ads.googleads.v22.resources.types.ad import Ad

_M = TypeVar("_M")

class AdGroupAd(proto.Message):
    resource_name: str
    status: AdGroupAdStatusEnum.AdGroupAdStatus
    ad_group: str
    ad: Ad
    policy_summary: AdGroupAdPolicySummary
    ad_strength: AdStrengthEnum.AdStrength
    action_items: MutableSequence[str]
    labels: MutableSequence[str]
    primary_status: AdGroupAdPrimaryStatusEnum.AdGroupAdPrimaryStatus
    primary_status_reasons: MutableSequence[
        AdGroupAdPrimaryStatusReasonEnum.AdGroupAdPrimaryStatusReason
    ]
    ad_group_ad_asset_automation_settings: MutableSequence[
        AdGroupAdAssetAutomationSetting
    ]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        status: AdGroupAdStatusEnum.AdGroupAdStatus = ...,
        ad_group: str = ...,
        ad: Ad = ...,
        policy_summary: AdGroupAdPolicySummary = ...,
        ad_strength: AdStrengthEnum.AdStrength = ...,
        action_items: MutableSequence[str] = ...,
        labels: MutableSequence[str] = ...,
        primary_status: AdGroupAdPrimaryStatusEnum.AdGroupAdPrimaryStatus = ...,
        primary_status_reasons: MutableSequence[
            AdGroupAdPrimaryStatusReasonEnum.AdGroupAdPrimaryStatusReason
        ] = ...,
        ad_group_ad_asset_automation_settings: MutableSequence[
            AdGroupAdAssetAutomationSetting
        ] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "resource_name",
            "status",
            "ad_group",
            "ad",
            "policy_summary",
            "ad_strength",
            "action_items",
            "labels",
            "primary_status",
            "primary_status_reasons",
            "ad_group_ad_asset_automation_settings",
        ],
    ) -> bool: ...

class AdGroupAdAssetAutomationSetting(proto.Message):
    asset_automation_type: AssetAutomationTypeEnum.AssetAutomationType
    asset_automation_status: AssetAutomationStatusEnum.AssetAutomationStatus
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        asset_automation_type: AssetAutomationTypeEnum.AssetAutomationType = ...,
        asset_automation_status: AssetAutomationStatusEnum.AssetAutomationStatus = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["asset_automation_type", "asset_automation_status"]
    ) -> bool: ...

class AdGroupAdPolicySummary(proto.Message):
    policy_topic_entries: MutableSequence[PolicyTopicEntry]
    review_status: PolicyReviewStatusEnum.PolicyReviewStatus
    approval_status: PolicyApprovalStatusEnum.PolicyApprovalStatus
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        policy_topic_entries: MutableSequence[PolicyTopicEntry] = ...,
        review_status: PolicyReviewStatusEnum.PolicyReviewStatus = ...,
        approval_status: PolicyApprovalStatusEnum.PolicyApprovalStatus = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["policy_topic_entries", "review_status", "approval_status"]
    ) -> bool: ...



from .base import CampaignDraftServiceTransport as CampaignDraftServiceTransport
from .grpc import CampaignDraftServiceGrpcTransport as CampaignDraftServiceGrpcTransport
from .grpc_asyncio import (
    CampaignDraftServiceGrpcAsyncIOTransport as CampaignDraftServiceGrpcAsyncIOTransport,
)

__all__ = [
    "CampaignDraftServiceTransport",
    "CampaignDraftServiceGrpcTransport",
    "CampaignDraftServiceGrpcAsyncIOTransport",
]



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

_M = TypeVar("_M")

class CampaignCriterionStatusEnum(proto.Message):
    class CampaignCriterionStatus(proto.Enum):
        UNSPECIFIED = 0
        UNKNOWN = 1
        ENABLED = 2
        PAUSED = 3
        REMOVED = 4

    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: NoReturn
    ) -> bool: ...



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v20.enums.types.listing_group_filter_custom_attribute_index import (
    ListingGroupFilterCustomAttributeIndexEnum,
)
from google.ads.googleads.v20.enums.types.listing_group_filter_listing_source import (
    ListingGroupFilterListingSourceEnum,
)
from google.ads.googleads.v20.enums.types.listing_group_filter_product_category_level import (
    ListingGroupFilterProductCategoryLevelEnum,
)
from google.ads.googleads.v20.enums.types.listing_group_filter_product_channel import (
    ListingGroupFilterProductChannelEnum,
)
from google.ads.googleads.v20.enums.types.listing_group_filter_product_condition import (
    ListingGroupFilterProductConditionEnum,
)
from google.ads.googleads.v20.enums.types.listing_group_filter_product_type_level import (
    ListingGroupFilterProductTypeLevelEnum,
)
from google.ads.googleads.v20.enums.types.listing_group_filter_type_enum import (
    ListingGroupFilterTypeEnum,
)

_M = TypeVar("_M")

class AssetGroupListingGroupFilter(proto.Message):
    resource_name: str
    asset_group: str
    id: int
    type_: ListingGroupFilterTypeEnum.ListingGroupFilterType
    listing_source: ListingGroupFilterListingSourceEnum.ListingGroupFilterListingSource
    case_value: ListingGroupFilterDimension
    parent_listing_group_filter: str
    path: ListingGroupFilterDimensionPath
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        asset_group: str = ...,
        id: int = ...,
        type_: ListingGroupFilterTypeEnum.ListingGroupFilterType = ...,
        listing_source: ListingGroupFilterListingSourceEnum.ListingGroupFilterListingSource = ...,
        case_value: ListingGroupFilterDimension = ...,
        parent_listing_group_filter: str = ...,
        path: ListingGroupFilterDimensionPath = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "resource_name",
            "asset_group",
            "id",
            "type_",
            "listing_source",
            "case_value",
            "parent_listing_group_filter",
            "path",
        ],
    ) -> bool: ...

class ListingGroupFilterDimension(proto.Message):
    class ProductBrand(proto.Message):
        value: str
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            value: str = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["value"]
        ) -> bool: ...

    class ProductCategory(proto.Message):
        category_id: int
        level: ListingGroupFilterProductCategoryLevelEnum.ListingGroupFilterProductCategoryLevel
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            category_id: int = ...,
            level: ListingGroupFilterProductCategoryLevelEnum.ListingGroupFilterProductCategoryLevel = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["category_id", "level"]
        ) -> bool: ...

    class ProductChannel(proto.Message):
        channel: ListingGroupFilterProductChannelEnum.ListingGroupFilterProductChannel
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            channel: ListingGroupFilterProductChannelEnum.ListingGroupFilterProductChannel = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["channel"]
        ) -> bool: ...

    class ProductCondition(proto.Message):
        condition: (
            ListingGroupFilterProductConditionEnum.ListingGroupFilterProductCondition
        )
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            condition: ListingGroupFilterProductConditionEnum.ListingGroupFilterProductCondition = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["condition"]
        ) -> bool: ...

    class ProductCustomAttribute(proto.Message):
        value: str
        index: ListingGroupFilterCustomAttributeIndexEnum.ListingGroupFilterCustomAttributeIndex
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            value: str = ...,
            index: ListingGroupFilterCustomAttributeIndexEnum.ListingGroupFilterCustomAttributeIndex = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["value", "index"]
        ) -> bool: ...

    class ProductItemId(proto.Message):
        value: str
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            value: str = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["value"]
        ) -> bool: ...

    class ProductType(proto.Message):
        value: str
        level: ListingGroupFilterProductTypeLevelEnum.ListingGroupFilterProductTypeLevel
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            value: str = ...,
            level: ListingGroupFilterProductTypeLevelEnum.ListingGroupFilterProductTypeLevel = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["value", "level"]
        ) -> bool: ...

    class Webpage(proto.Message):
        conditions: MutableSequence[ListingGroupFilterDimension.WebpageCondition]
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            conditions: MutableSequence[
                ListingGroupFilterDimension.WebpageCondition
            ] = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["conditions"]
        ) -> bool: ...

    class WebpageCondition(proto.Message):
        custom_label: str
        url_contains: str
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            custom_label: str = ...,
            url_contains: str = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["custom_label", "url_contains"]
        ) -> bool: ...

    product_category: ListingGroupFilterDimension.ProductCategory
    product_brand: ListingGroupFilterDimension.ProductBrand
    product_channel: ListingGroupFilterDimension.ProductChannel
    product_condition: ListingGroupFilterDimension.ProductCondition
    product_custom_attribute: ListingGroupFilterDimension.ProductCustomAttribute
    product_item_id: ListingGroupFilterDimension.ProductItemId
    product_type: ListingGroupFilterDimension.ProductType
    webpage: ListingGroupFilterDimension.Webpage
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        product_category: ListingGroupFilterDimension.ProductCategory = ...,
        product_brand: ListingGroupFilterDimension.ProductBrand = ...,
        product_channel: ListingGroupFilterDimension.ProductChannel = ...,
        product_condition: ListingGroupFilterDimension.ProductCondition = ...,
        product_custom_attribute: ListingGroupFilterDimension.ProductCustomAttribute = ...,
        product_item_id: ListingGroupFilterDimension.ProductItemId = ...,
        product_type: ListingGroupFilterDimension.ProductType = ...,
        webpage: ListingGroupFilterDimension.Webpage = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "product_category",
            "product_brand",
            "product_channel",
            "product_condition",
            "product_custom_attribute",
            "product_item_id",
            "product_type",
            "webpage",
        ],
    ) -> bool: ...

class ListingGroupFilterDimensionPath(proto.Message):
    dimensions: MutableSequence[ListingGroupFilterDimension]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        dimensions: MutableSequence[ListingGroupFilterDimension] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["dimensions"]
    ) -> bool: ...



from typing import Awaitable, Callable, Sequence

import grpc
from google.api_core import gapic_v1
from google.auth import credentials as ga_credentials
from grpc.experimental import aio  # type: ignore[attr-defined]

from google.ads.googleads.v22.services.types import ad_group_service

from .base import AdGroupServiceTransport

__all__ = ["AdGroupServiceGrpcAsyncIOTransport"]

class _LoggingClientAIOInterceptor(grpc.aio.UnaryUnaryClientInterceptor):
    async def intercept_unary_unary(
        self, continuation, client_call_details, request
    ): ...

class AdGroupServiceGrpcAsyncIOTransport(AdGroupServiceTransport):
    @classmethod
    def create_channel(
        cls,
        host: str = "googleads.googleapis.com",
        credentials: ga_credentials.Credentials | None = None,
        credentials_file: str | None = None,
        scopes: Sequence[str] | None = None,
        quota_project_id: str | None = None,
        **kwargs,
    ) -> aio.Channel: ...
    def __init__(
        self,
        *,
        host: str = "googleads.googleapis.com",
        credentials: ga_credentials.Credentials | None = None,
        credentials_file: str | None = None,
        scopes: Sequence[str] | None = None,
        channel: aio.Channel | Callable[..., aio.Channel] | None = None,
        api_mtls_endpoint: str | None = None,
        client_cert_source: Callable[[], tuple[bytes, bytes]] | None = None,
        ssl_channel_credentials: grpc.ChannelCredentials | None = None,
        client_cert_source_for_mtls: Callable[[], tuple[bytes, bytes]] | None = None,
        quota_project_id: str | None = None,
        client_info: gapic_v1.client_info.ClientInfo = ...,
        always_use_jwt_access: bool | None = False,
        api_audience: str | None = None,
    ) -> None: ...
    @property
    def grpc_channel(self) -> aio.Channel: ...
    @property
    def mutate_ad_groups(
        self,
    ) -> Callable[
        [ad_group_service.MutateAdGroupsRequest],
        Awaitable[ad_group_service.MutateAdGroupsResponse],
    ]: ...
    def close(self): ...
    @property
    def kind(self) -> str: ...



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from google.rpc.status_pb2 import Status
from typing_extensions import Literal

from google.ads.googleads.v22.enums.types.asset_field_type import AssetFieldTypeEnum

_M = TypeVar("_M")

class RemoveCampaignAutomaticallyCreatedAssetOperation(proto.Message):
    campaign: str
    asset: str
    field_type: AssetFieldTypeEnum.AssetFieldType
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        campaign: str = ...,
        asset: str = ...,
        field_type: AssetFieldTypeEnum.AssetFieldType = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["campaign", "asset", "field_type"]
    ) -> bool: ...

class RemoveCampaignAutomaticallyCreatedAssetRequest(proto.Message):
    customer_id: str
    operations: MutableSequence[RemoveCampaignAutomaticallyCreatedAssetOperation]
    partial_failure: bool
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        operations: MutableSequence[
            RemoveCampaignAutomaticallyCreatedAssetOperation
        ] = ...,
        partial_failure: bool = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["customer_id", "operations", "partial_failure"]
    ) -> bool: ...

class RemoveCampaignAutomaticallyCreatedAssetResponse(proto.Message):
    partial_failure_error: Status
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        partial_failure_error: Status = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["partial_failure_error"]
    ) -> bool: ...
